# Rappel

## Fonctions

Une fonction $f$ de façon générale est un objet qui prend un (ou plusieurs) paramètres et qui lui (leur) associe un résultat
$$
\mbox{résultat}=f(\mbox{paramètres}).
$$
Nous pouvons aussi exprimer cette notion de la manière suivante. Considérons deux ensembles $A$ et $B$. Supposons qu'à chaque élément $x\in A$ est associé un élément dans $B$ que nous notons par $f(x)$. Alors on dit que $f$ est une fonction ou une application (de $A$ dans $B$). A ce niveau A et B sont arbitraires mais dans la suite nous allons nous intéresser surtout du cas où $A\subseteq\real$. $A$ est le *domaine de définition* de $f$. Les valeurs de $f$ constituent les *images* de $x$.

---

#### Exemple (Fonctions, généralités) {-}

1. La tension $U$ est une fonction de la résistance $R$ et du courant
    $I$ $$\begin{aligned}
    U=f(R,I)=R\cdot I.\end{aligned}$$

2. Une fonction peut être quelque chose de beaucoup plus général (qu’on
    ne peut pas forcément représenter simplement avec des opérateurs
    mathématiques). Prenons le cas de la fonction qui pour un nombre
    entier $x$ rend le prochain entier dont le nom commence par la même lettre
    que $x$. $$f(2)=10,\ f(3)=13,\ ...$$

---

Dans ce cours nous allons nous intéresser à des fonctions à un seul
paramètre (aussi appelé variable). Si on note la variable $x$ et le
résultat $y$, de façon générale on peut écrire $$y = f(x).$$ Si par
ailleurs on a une fonction $g$ et une fonction $f$, on peut effectuer
des compositions de fonction, qu’on note $g\circ f$, ou encore
$$y=g(f(x)).$$

---

#### Exemple (Fonctions) {-}

1. Soit $f(x)=2\cdot x$ et $g(x)=\sqrt{x}$, alors la composition des
    deux fonctions $$(f\circ g)(x)=f(g(x))=f(\sqrt{x})=2\sqrt{x}.$$

2. On peut composer un nombre arbitraire de fonctions. Voyons le cas
    avec trois fonctions $f(x)=2x^2+3$, $g(x)=\cos(2\cdot x)$, et
    $h(x)=1/x$ $$f(g(h(x)))=f(g(1/x))=f(\cos(2/x))=2\cos^2(2/x)+3.$$

---

Pour certaines fonctions, notons les $f(x)$, on peut également définir
une fonction inverse que l’on note $f^{-1}(x)$ dont la composition donne
la variable de départ $$f(f^{-1}(x))=x.$$

---

#### Exemple (Fonction inverse) {-}

1. Soient $f(x)=2\cdot x$ et $f^{-1}(x)=x/2$, alors la composition des
    deux fonctions $$f(f^{-1}(x))=f(x/2)=2x/2=x.$$

2. Soient $f(x)=x^2$ et $f^{-1}(x)=\sqrt{x}$, alors la composition des
    deux fonctions $$f(f^{-1}(x))=f(\sqrt{x})=|x|.$$ On a donc que
    $\sqrt{x}$ est l’inverse de $x^2$ uniquement pour les réels
    positifs. $f(x)=x^2$ n’a pas d’inverse pour les $x$ négatifs.
    On peut se convaincre qu'une fonction ne peu admettre une inverse que si elle
    elle satisfait la condition $x_1\neq x_2 \rightarrow f(x_1)\neq f(x_2)$.
    Dans notre exemple $-1\neq 1$ mais $(f(-1)=f(1)=1$

---

## Domaine de définition


#### Définition (Domaine de définition) {-}

Le domaine de définition, noté $D\subset{\real}$, d’une fonction
$f$, est l’ensemble de valeurs où $f$ admet une image.

---

#### Exemple (Domaine de définition) {-}

1. Le domaine de définition de $f(x)=x$ est $D={\real}$.

2. Le domaine de définition de $f(x)=1/x$ est $D={\real}^\ast$.

3. Le domaine de définition de $f(x)=\sqrt{x+1}/(x-10)$ est
    $D=[-1;10[\cup]10;\infty[$.

---

## Limites

Soit $f$ une fonction et $D\subseteq{\real}$ non-vide  et soient $a$ et $b$ deux réels.

### Limite

#### Définition (Limite) {-}

Pour $f$ définie en $D$,  on dit que $b$ est la
limite de $x$ en $a$ si si au fur et à mesure que $x$ se rapproche de $a$, $f(x)$ se rapproche de $b$ et nous notons  $\lim\limits_{x\rightarrow a}f(x)=b$.
C’est-à-dire pour tout voisinage de $b$ qui contient toutes  les valeurs
de $f(x)$ nous avons un voisinage de $a$ qui contient les valeurs de $x$ (suffisamment proches de $a$).

La définition mathématique plus stricte est:

*Pour tout $\varepsilon > 0$, il existe un $\delta >0$, tel que, pour tout $x\in D$ tel que $|x-a|<\delta$, on ait $|f(x)-a|<\varepsilon$.*

Ou encore quand le but est d'écrire ça de la façon la plus compacte possible

$$\forall\varepsilon>0,\exists\delta>0\ |\ \forall x\in D,\ |x-a|<\delta\Rightarrow|f(x)-b|<\varepsilon.$$

#### Remarque {-}

Il n'est pas nécessaire que $a\in D$. Mais si c'est le cas et donc
$f$ est définie en $a$ alors on a $\lim\limits_{x\rightarrow a}=f(a)$.

---

#### Exemple (Limite) {-}

Si $f(x)=x$, alors $\lim\limits_{x\rightarrow 0}f(x)=0$.

---

#### Définition (Limite, asymptote) {-}

Pour $f$ définie en $D$,
on dit que la limite de $f(x)$ en $a$ est égale à l’infini si pour tout $c>0$ l’intervalle
$[c;\infty[$ contient toutes les valeurs de $f(x)$ pour $x$ suffisamment proche de
$a$. On dit aussi que $f$ tend vers l'infini.

---

#### Exemple (Limite, asymptote) {-}

Si $f(x)=1/x^2$, alors $\lim\limits_{x\rightarrow 0}f(x)=\infty$.

---

### Limite à gauche, limite à droite

Il est possible que le comportement de certaines fonctions
soit différent selon qu’on approche $a$  par la gauche ou par la
droite (i.e. $f(x)=1/x$, pour $a=0$).

On note la limite à droite $\lim\limits_{x\rightarrow a^+} f(x)$ ou
$\lim\limits_{x\rightarrow a,x>a} f(x)$ et
$\lim\limits_{x\rightarrow a^-} f(x)$ ou
$\lim\limits_{x\rightarrow a,x<a} f(x)$ la limite à gauche de la
fonction $f$ en $a$.

Si la fonction $f$ admet une limite en $a$, alors les deux limites
sont égales.

#### Exemple (Limite à gauche/droite) {-}

Si $f(x)=1/x$, alors $\lim\limits_{x\rightarrow 0^+} f(x)=\infty$ et
$\lim\limits_{x\rightarrow 0^-} f(x)=-\infty$.

### Comportement asymptotique

Dans certains cas il peut être intéressant d’étudier le comportement des
fonctions quand $x\rightarrow\pm\infty$. Dans ces cas-là on dit qu’on
s’intéresse au comportement *asymptotique* d’une fonction. Ce concept
est particulièrement pertinent quand on étudie une fonction qui a la
forme d’une fraction $$h(x)=\frac{f(x)}{g(x)}.$$ Si on s’intéresse au
comportement à l’infini de cette fonction on va prendre sa “limite”
lorsque $x\rightarrow\infty$
$$\lim_{x\rightarrow\infty} h(x)=\lim_{x\rightarrow\infty}\left(\frac{f(x)}{g(x)}\right).$$
Un exemple peut être $f(x)=x-1$, $g(x)=x+1$ et donc $h(x)=(x-1)/(x+1)$
$$\lim_{x\rightarrow\infty} \frac{x-1}{x+1}=\lim_{x\rightarrow\infty} \frac{x(1-1/x)}{x(1+1/x)}=1.$$
De même quand on a $f(x)=3x^4-5x^3+1$, $g(x)=1$ et donc
$h(x)=3x^4-5x^3+1$. Il vient donc
$$\lim_{x\rightarrow\infty} 3x^4-5x^3+1=\lim_{x\rightarrow\infty}3x^4\left(1-\frac{5}{3x}+\frac{1}{3x^4}\right)=\infty.$$

Si nous compliquons un peu l’exemple et que nous avons
$f(x)=x^3+3x^2+1$, $g(x)=x^2$ et donc $h(x)=(x^3+3x^2+1)/x^2$
$$\lim_{x\rightarrow\infty} (x^3+3x^2+1)/x^2=\lim_{x\rightarrow\infty} x=\infty.$$
Un cas encore un peu plus complexe serait
$f(x)=3x^3+1$, $g(x)=4x^3+2x^2+x$
$$
\lim_{x\rightarrow \infty}\frac{f(x)}{g(x)}=\lim_{x\rightarrow \infty}\frac{3x^3(1+1/3x^3)}{4x^3(1+1/2x^+1/4x^2)}=\frac{3}{4}.$$

Ce genre d’estimations est important en informatique lors de l’analyse de
performance des algorithmes. On peut prendre l’exemple des algorithmes
de tri “bubble sort” et “quick sort”. Leur complexité respective moyenne
est de $n^2$ et de $n\log(n)$, quand $n$ est le nombre d’éléments de la
chaîne à trier. Si on fait le rapport pour de ces deux complexités on a
$$\lim_{n\rightarrow\infty} \frac{n^2}{n\log(n)}=\lim_{n\rightarrow\infty} \frac{n}{\log(n)}.$$
On peut simplement voir que ce rapport va tendre vers l’infini en
dessinant la courbe $n/\log(n)$. Il existe un moyen “analytique”
d’évaluer ce rapport. Tout nombre $n$ peut s’écrire avec une précision
$p$ comme $$n=A\cdot 10^{p-1},$$ où $p$ est le nombre de chiffres
significatifs qu’on veut représenter, et $1\leq A< 10$. On a également
que[^1]
$$\log(A)=\log\left(\frac{1+y}{1-y}\right)=2\sum_{k=0}^\infty \frac{y^{2k+1}}{2k+1},$$
avec $y=(A-1)/(A+1)$. On a finalement que
$$\log(n)=\log(A\cdot 10^{p-1})=(p-1)\log(10)+2\sum_{k=0}^\infty \frac{y^{2k+1}}{2k+1}.$$
La valeur de $y$ étant quelque chose de proche de 0, la somme converge
vite vers une valeur finie et on peut faire l’approximation
$$\log(n)\cong(p-1)\log(10),$$ pour $n$ grand (ce qui est équivalent à
$p$ grand). On a donc que finalement le rapport $n/\log(n)$ va comme
$$\lim_{n\rightarrow\infty}\frac{n}{\log(n)}=\frac{A}{\log(10)}\cdot\lim_{p\rightarrow\infty}\frac{10^{p-1}}{(p-1)}=\frac{A}{\log(10)}\cdot\lim_{p\rightarrow\infty}\frac{10^{p-1}}{p}=\infty.$$

## Continuité

#### Définition (Continuité) {-}

Soit $f$ une fonction définie sur un intervalle ouvert $D$ contenant
$a$. On dit que $f$ est continue en $a$ si et seulement si
$\lim\limits_{x\rightarrow a}f(x)=f(a)$.

#### Propriétés (Fonctions continues) {-}

Soient $f$ et $g$ deux fonctions continues en $a$ et $b$ un réel:

1. $f+g$ est continue en $a$.

2. $b f$ est continue en $a$.

3. si $g(a)\neq 0$, $f/g$ est continue en $a$.

4. $h=g\circ f$ est continue en $a$.

#### Définition (Continuité sur un intervalle) {-}

Une fonction $f$ est dite continue dans un intervalle $D=]a;b[$ si et
seulement si elle est continue en tout point de $D$. De plus, elle est
continue sur $D=[a,b]$ si elle est continue sur $]a;b[$ et continue à
droite en $a$ et à gauche en $b$.

#### Théorème (Valeurs intermédiaires) {-}

Soit $f$ une fonction continue
sur $D$, et $a,b$ deux points contenus dans $D$ tels que $a<b$ et
$f(a)<f(b)$, alors $$\forall y\in [f(a);f(b)],\ \exists\ c\in [a,b] |f(c)=y.$$
Nous pouvons bien sûr énoncer un résultat similaire dans le cas $f(a9>f(b)$.

## Dérivées

#### Définition (Dérivée en un point) {-}

Soit $f$ une fonction définie sur $D$ et $a\in D$. On dit que $f$ est
dérivable en $a$ s’il existe un $b$ (appelé la dérivée de $f$ en $a$)
tel que $$\begin{aligned}
&\lim\limits_{h\rightarrow 0}\frac{f(a+h)-f(a)}{h}=b,\hbox{ ou}\\
&\lim\limits_{x\rightarrow a}\frac{f(x)-f(a)}{x-a}=b.\end{aligned}$$

#### Définition (Dérivée sur un intervalle) {-}

Si $f$ est dérivable en tout point de $D=]a;b[$, alors on définit $f'$
la fonction dérivée de $f$ dans l’intervalle $D$ qui associe en tout
point $x$ de $D$ la valeur dérivée de $f$.

#### Propriété {-}

Si $f$ est dérivable en $a$ alors $f$ est continue en $a$.

#### Propriétés {-}

Soient $f$ et $g$ deux fonctions dérivables sur $D$ (dont les dérivées sont $f'$
et $g'$), et $a\in{\real}$, alors

1. $(f+g)'=f'+g'$.

2. $(af)'=a f'$.

3. $(f\cdot g)'=f'g+fg'$.

4. Si $g$ ne s'annule pas  $(f/g)'=(f'g-fg')/g^2$.

5. $(g\circ f)'=(g'\circ f)\cdot f'$, autrement dit pour $x\in D$, $(g(f(x)))'=g'(f(x)\cdot f'(x)$.

Il existe quelques dérivées importantes que nous allons utiliser
régulièrement dans la suite de ce cours. En supposons que
$C\in {\real}$, nous avons

1. $f(x)=x^n$, $f'(x)=nx^{n-1}$ .

2. $f(x)=e^{C x}$, $f'(x)=Ce^{Cx}$.

3. $f(x)=\ln(x)$, $f'(x)=1/x$.

4. $f(x)=C$, $f'(x)=0$.

5. $f(x)=\sin(x)$, $f'(x)=\cos(x)$.

6. $f(x)=\cos(x)$, $f'(x)=-\sin(x$).

#### Définition (Dérivée seconde) {-}

Si $f'$ est dérivable sur $D$, alors sa dérivée, notée $f''$, est
appelée la dérivée seconde de $f$.

### Variation des fonctions

#### Propriétés (Croissance/décroissance) {-}

Soit $f'$ la fonction dérivée de $f$ sur $D$

1. Si $f'>0$ sur $D$, alors $f$ est croissante sur $D$.

2. Si $f'<0$ sur $D$, alors $f$ est décroissante sur $D$.

3. Si $f'=0$ sur $D$, alors $f$ est constante sur $D$.

#### Définition (Maximum/minimum local) {-}

Une fonction admet un maximum local (respectivement minimum local) sur
un intervalle $D=]a;b[$ s’il existe un $x_0\in D$ tel que $f(x_0)\geq f(x)$
(respectivement $f(x_0)\leq f(x)$) pour tout $x\in D$.

#### Propriété (Maximum/minimum) {-}

Soient $f$ une fonction dérivable sur $D=]a;b[$ et $x_0\in D$. On dit que $f$
admet un extremum en $x_0$ si $f'(x_0)=0$. De plus si
$f'(x_0)=0$ et $f'$ change de signe en $x_0$ alors $f(x_0)$ est un
maximum ou un minimum de $f$.

## Etude de fonction

Effectuer l’étude de fonction de la fonction suivante
$$f(x)=\frac{x^3}{x^2-4}.$$

1. Déterminer le domaine de définition.

2. Déterminer la parité de la fonction. Rappel: $$\begin{aligned}
      f(-x)&=f(x),\ \mbox{paire},\\
      f(-x)&=-f(x),\ \mbox{impaire}.
     \end{aligned}$$

3. Trouver les zéros de la fonction (Indication: trouver les $x$ tels
    que $f(x)=0$).

4. Trouver les éventuelles asymptotes verticales ou discontinuités,
    ainsi que les asymptotes affines.

5. Calculer $f'(x)$ et déterminer sa croissance et points critiques
    (déterminer où la fonction est croissante, décroissante, atteint un
    extremum, etc).

6. Faire un croquis de $f(x)$.
