Transformées de Fourier
=======================

Rappel sur les nombres complexes
--------------------------------

Dans cette section, on fait un rappel sur les nombres complexes qui
seront beaucoup utilisés dans la suite.

### Les nombres réels

L’ensemble des nombres réels, noté ${\real}$, est doté  d'un certain
nombre de fonctions (opérateurs) tels que l’addition,
la multiplication etc qui prennent un couple de nombres
réels et rendent un autre nombre réel $$\begin{aligned}
& +:{\real}\times{\real}\rightarrow{\real},\\
& \ \cdot:{\real}\times{\real}\rightarrow{\real},\\\end{aligned}$$
De la définition de  l’addition de deux nombres réels il vient par exemple que
$$+(7,2)=9.$$ On  préfère la notation
$$+(7,2)=7+2=9.$$ Intéressons nous plus particulièrement à la
multiplication et à l’addition. Ces opérations ont les propriétés
d’associativité et de commutativité. Cela veut dire que
$$\begin{aligned}
 &(a+b)+c=a+(b+c), &(a\cdot b)\cdot c=a\cdot(b\cdot c),\\
 &\quad\quad\quad\quad\quad\quad\mbox{ et }&\nonumber\\
 &a+b=b+a,&a\cdot b=b\cdot a.\end{aligned}$$

### Les couples de nombres réels

Intéressons-nous à présent à un ensemble plus grand que ${\real}$,
soit ${\real}^2\equiv{\real}\times{\real}$. Cet ensemble
est l’ensemble des des couples de nombres réels. Notons les nombres
$z\in{\real}^2$ comme
$$z=(a,b)\mbox{ tel que } a\in{\real}, \mbox{ et } b\in{\real}.$$
Sur ces nombres on peut définir à nouveau l’addition,
la multiplication, ... $$\begin{aligned}
& +:{\real}^2\times{\real}^2\rightarrow{\real}^2,\\
& \cdot:{\real}^2\times{\real}^2\rightarrow{\real}^2.\end{aligned}$$
On peut les écrire sous la forme de leurs équivalents des nombres réels
comme
$$(a,b)+(c,d)=(a+c,b+d),$${#eq:add}
$$(a,b)\cdot(c,d)=(a\cdot c-b\cdot d,a\cdot d+b\cdot c).$${#eq:mult}
On voit assez facilement que l’addition sur ${\real}^2$ a une forme
très similaire à celle sur ${\real}$ du point de vue de ses
propriétés telles que la commutativité ou l’associativité. Cela est
moins clair pour la multiplication. Il est néanmoins assez simple de
vérifier la commutativité $$\begin{aligned}
(a,b)\cdot(c,d)&=(a\cdot c-b\cdot d,a\cdot d+b\cdot c)\nonumber\\
&=(c\cdot a-d\cdot b,d\cdot a+c\cdot b)=(c,d)\cdot (a,b).\end{aligned}$$

#### Exercice {-}

Vérifier l’associativité du produit sur notre ensemble ${\real}^2$.

Regardons à présent ce qui se passe si on étudie les ensemble de
nombres dans ${\real}^2$ où le deuxième nombre du couple est nul tels que $(a,0)$. Si on additionne
deux tels nombres ont obtient $$(a,0)+(b,0)=(a+b,0).$$ On constate donc
que ce genre de nombre se comporte exactement comme un nombre réel
normal du point de vue de l’addition. Que se passe-t-il quand on
multiplie deux tels nombres
$$(a,0)\cdot(b,0)=(a\cdot b-0\cdot 0,a\cdot 0+0\cdot b)=(a\cdot b,0).$$
On voit que pour la multiplication également les ensembles de nombres
dont le deuxième est nul, se comporte comme un nombre réel standard.

En fait on peut montrer que ce sous-ensemble de ${\real}^2$ se
comporte exactement comme ${\real}$. Il se trouve donc que
${\real}^2$ est un ensemble plus grand que ${\real}$
et qui le contient entièrement.

### Les nombres complexes

Afin de simplifier les notations et les calculs, on peut introduire une
notation différente. Introduisons donc le *nombre imaginaire* $i$ tel
que $$(a,b)=a+i\cdot b.$$ On va maintenant définir l’ensemble des
nombres complexes $z\in{\mathbb{C}}$ comme tout nombre qui peut s’écrire
sous la forme $$z=a+i\cdot b.$$ Avec l’addition que nous avons définie à
l'@eq:add, nous avons avec la nouvelle notation
$$(a,b)+(c,d)=(a+c,b+d)\Leftrightarrow(a+i\cdot b)+(c+i\cdot d)=(a+c)+i(b+d).$$
On constate que les nombres multipliés par $i$ sépare nos couples de
nombres (les empêche “de se mélanger”),

Pour la multiplication nous avons de même par la définition (équation
@eq:mult)
$$(a,b)\cdot(c,d)=(ac-bd,ad+bc)\Leftrightarrow(a+i\cdot b)\cdot(c+i\cdot d)=(ac-bd)+i(ad+bc).$${#eq:res_mult}
Si maintenant nous utilisons la multiplication de manière classique avec
notre nouvelle notation (on distribue le produit comme pour les réels)
$$(a+i\cdot b)\cdot(c+i\cdot d)=ac+i^2\cdot bd+i(ad+bc).$$ On constate
donc que pour que cette équation soit égale à l’équation
@eq:res_mult on doit avoir que $i^2=-1$. Il se trouve que c’est
la définition formelle du nombre imaginaire. Dans les réels $i$ ne peut
pas exister. En revanche dans l’espace plus grand des complexes $i$ a
une existence tout à fait naturelle et raisonnable. En fait le nombre
$i$ est associé au couple $(0,1)$ comme on voit par $(0,19\cdot (0,1)=(-1,0)$.

On appelle partie réelle d’un nombre complexe $z$, la partie pas
multipliée par $i$ (on la note ${\mathrm{Re}}(z)$) et  partie
imaginaire celle multipliée par $i$ (on la note ${\mathrm{Im}}(z)$).
Pour $z=a+ib$, on a donc ${\mathrm{Re}}(z)=a$ et ${\mathrm{Im}}(z)=b$.

#### Interprétation géométrique

Comme on l’a vu précédemment, les nombres complexes peuvent se voir
comme une “notation” de ${\real}^2$. On peut ainsi les représenter
sur un plan bidimensionnel (voir la @fig:complexPlane).

![Représentation du nombre complexe $z=a+ib$.](figs/complexPlane.svg){#fig:complexPlane width="35.00000%"}

La somme de deux nombres complexes s’interprète également facilement de
façon graphique. On peut le voir sur la @fig:complexPlaneSum.
Il s’agit en fait de simplement faire la somme des vecteurs représentant
chacun des nombres complexes à sommer.

![Représentation de la somme de deux nombres complexes $z_1=a+ib$ et
$z_2=c+id$. Le résultat est donné par
$z_3=a+c+i(b+d)$.](figs/complexPlaneSum.svg){#fig:complexPlaneSum width="50.00000%"}

Pour la multiplication cela s’avère un peu plus difficile à interpréter.
Pour cela il est plus simple de passer par une représentation via des
sinus et des cosinus (en coordonnées polaires) des nombres complexes
(voir la @fig:complexPlaneCyl.

![Représentation du nombre complexe
$z=a+ib$.](figs/complexPlaneCyl.svg){#fig:complexPlaneCyl width="35.00000%"}

En utilisant la représentation en termes de $\vartheta$ et $r$, on a que
$z=r(\cos\vartheta+i\sin\vartheta)=a+ib$. On a immédiatement les
relations suivantes entre ces deux représentations $$\begin{aligned}
 r=\sqrt{a^2+b^2},\\
 \cos\vartheta=\frac{a}{r},\\
 \sin\vartheta=\frac{b}{r}.\end{aligned}$$ On dit que $r$ est le
*module* de $z$ (aussi noté $|z|$) et que $\vartheta$ est son *argument*
(aussi noté $\arg(z)$).

Si à présent on définit $z_1=r_1(\cos\vartheta_1+i\sin\vartheta_1)$ et
$z_2=r_2(\cos\vartheta_2+i\sin\vartheta_2)$, on a que $z_3=z_1\cdot z_2$
devient $$\begin{aligned}
 z_3=r_1r_2\left(\cos\vartheta_1\cos\vartheta_2-\sin\vartheta_1\sin\vartheta_2+i\left(\cos\vartheta_1\sin\vartheta_2+\cos\vartheta_2\sin\vartheta_1\right)\right).\end{aligned}$$
En utilisant les relations trigonométriques suivantes $$\begin{aligned}
 \cos\vartheta_1\cos\vartheta_2-\sin\vartheta_1\sin\vartheta_2&=\cos(\theta_1+\theta_2),\\
 \cos\vartheta_1\sin\vartheta_2+\cos\vartheta_2\sin\vartheta_1&=\sin(\theta_1+\theta_2),\end{aligned}$$
il vient $$\begin{aligned}
 z_3=r_1r_2\left(\cos(\vartheta_1+\vartheta_2)+i(\sin(\vartheta_1+\vartheta_2)\right).\end{aligned}$$
On a donc comme interprétation géométrique que le produit de deux
nombres complexe donne un nombre complexe dont la longueur (module) est le
produit des longueurs des nombres complexes originaux et dont
l’orientation (argument) est la somme des angles des nombres complexes originaux.

Cette propriété du produit nous amène à la notation sous forme
d’exponentielle des nombres complexes. L’exponentielle, possède la
propriété intéressante suivante $$e^a e^b=e^{a+b}.$$ Ou encore quand on
multiplie deux nombres représentés par une exponentielle, on peut
représenter le résultat par l’exponentielle de la somme de leurs
arguments. Comme pour les nombre complexes en somme. Il en découle des ces considérations 
que
$$z=re^{i\vartheta}=r(\cos\vartheta+i\sin\vartheta).$$

On peut démontrer de façon plus rigoureuse cette relation grâce aux
équations différentielles. On a vu dans le chapitre précédent que
l’équation différentielle $$f'(x)=\alpha f(x),\quad f(0)=r.$$ a pour
solution $f(x)=e^{\alpha x}$ ($\alpha\in{\mathbb{C}}$). Si on remplace
$\alpha$ par $i$, on a $f=e^{ix}$. Par ailleurs, avec $\alpha=i$, on
peut également vérifier que $f(x)=r(\cos x+i\sin x)$ satisfait
l’équation différentielle ci-dessus. On a donc bien que les deux formes
sont égales.Remarquons que $e^{ix}=\cos(x)+i\sin(x), x\in \real$ est la fameuse formule d'Euler.

#### Quelques notations et définitions

Pour la suite de ce cours, nous allons avoir besoin d’un certain nombre
de notations et de définition. En particulier, nous allons noter
$\bar{z}$ le nombre complexe conjugué de $z$. Soit $z=a+ib$, son
complexe conjugué ${\bar{z}}$ est donné par ${\bar{z}}=a-ib$. On voit
que le complexe conjugué a la même partie réelle que le nombre de
départ, mais une partie imaginaire opposée.

Lors de l’utilisation de la notation polaire d’un nombre complexe, nous
avons que le nombre complexe conjugué est de module égal, mais
d’argument opposé. En d’autres termes, si $z=re^{i\vartheta}$, alors
${\bar{z}}=re^{-i\vartheta}$.

On peut également écrire le module d’un nombre complexe à l’aide de la
notation du complexe conjugué. Il est donné par
$$|z|=\sqrt{z{\bar{z}}}.$$ Finalement, on peut également exprimer les
parties réelle et imaginaires d’un nombre complexe à l’aide de la
notation du complexe conjugué
$${\mathrm{Re}}(z)=\frac{1}{2}(z+{\bar{z}}),\quad {\mathrm{Im}}(z)=\frac{1}{2i}(z-{\bar{z}}).$$

---

#### Exercice {-}

Démontrer ces trois relations.

---

Rajoutons encore la relation entre $e^{i\theta}$ et les $\cos,\sin$.
$$\begin{aligned}
 \cos(\theta)=\frac{e^{i\theta}+e^{-i\theta}}{2},\\
 \sin(\theta)=\frac{e^{i\theta}-e^{-i\theta}}{2i}.\end{aligned}$$

---

#### Exercice {-}

Démontrer ces relations.

---

### Espaces vectoriels

Ici nous introduisons de façon très simplifiée le concept d’espace
vectoriel et certaines notions d’algèbre linéaire. Pour ce faire nous
allons considérer un ensemble $V$ muni d’une addition et d’une multiplication par un scalaire, c'est à dire par un nombre appartenant 
à un ensemble $E$. Dans notre cas $E$
sera ${\real}$ ou ${\mathbb{C}}$ (l'ensemble des nombres complexes)  principalement.

#### Définition {-}

On appelle espace vectoriel sur $E$, un ensemble $V$, dont les éléments
appelés vecteurs et notés $v$, sont sont munis des opérations 
$+$ (l’addition) et $\cdot$ (la multiplication par un scalaire) qui ont les
propriétés suivantes

-  

    1. L’addition est associative et commutative. Soient $u,v,w\in V$,
        alors $$u+v=v+u,\quad \mbox{ et }\quad (u+v)+w=u+(v+w).$$

    2. L’addition admet un élément neutre additif, noté $0_V$, tel que
        $$0_V+v=v.$$

    3. Tout $v$ admet un opposé, noté $-v$ tel que $$v+(-v)=0_V.$$

-  

    1. La multiplication par un scalaire est distributive à gauche sur
        l’addition (et à droite sur $E$). Pour $u,v\in V$ et
        $\alpha\in E$, on a
        $$\alpha\cdot(u+v)=\alpha\cdot u+\alpha\cdot v.$$

    2. La multiplication est associative par rapport à la
        multiplication de $E$. Soient $\alpha,\beta\in E$
        $$(\alpha\cdot\beta)\cdot v=\alpha\cdot(\beta\cdot v).$$

    3. La multiplication par un scalaire admet un élément neutre, noté
        $1$, pour la multiplication à gauche $$1 \cdot v=v.$$


#### Exemple (Espaces vectoriels) {-}

1. L’espace nul, $v=0$.

2. $V={\real}$ ou
    $V={\mathbb{C}}$ avec $E=\real$.

3. Espaces de $n-uplets$. Soit $V$ un espace vectoriel sur $E$.L’espace des $n-$uplets. Pour t$n>0$, l’ensemble des $n-$uplets
    d’éléments de $V$, $v=(v_1,v_2,...,v_n),\ \{v_i\in E\}_1^n$,
    est noté $V^n$. Sur cet espace l’addition se définit ($u,v\in V^n$)
    $$u+v=(u_1+v_1,u_2+v_2,...,u_v+v_n),$$ et la multiplication par un
    scalaire $\alpha\in E$
    $$\alpha v=(\alpha v_1,\alpha v_2,...,\alpha v_n).$$ On a donc que
    l’élément neutre de l’addition est le vecteur
    $0_{E^n}=\underbrace{(0,0,...,0)}_{n}$. L’élément opposé de $v$ est
    $-v=(-v_1,-v_2,...,-v_n)$.

    Si $V={\real}$, alors on a l’espace Euclidien. Vous avez
    l’habitude de l’utiliser en 2D ou 3D quand vous considérez des
    vecteurs. Dans ce cas ${\real}^2$ ou ${\real}^3$ avec
    l’addition classique et la multiplication par un réel
    forme un espace vectoriel.

4. Dans ce qui suit dans ce cours, nous allons utiliser encore un autre
    espace vectoriel un peu moins intuitif que ceux que nous avons vus
    jusqu’ici. Il s’agit de l’espace des fonctions, ou espace
    fonctionnel. Nous définissons les applications de $W$ dans $V$ comme
    un espace vectoriel dans $E$ avec l’addition et la multiplication
    par un scalaire définis comme suit. Soient $f:W\rightarrow V$ et
    $g:W\rightarrow V$, avec $\alpha\in E$, alors $$\begin{aligned}
       &(f+g)(x)=f(x)+g(x), \quad \forall x\in W,\\
       &(\alpha\cdot f)(x)=\alpha\cdot f(x), \quad \forall x\in W.
      \end{aligned}$$

5. Espace des applications linéaires. Soit $f$ une fonction de
    $f:W\rightarrow V$, avec $W,V$  des espaces vectoriels sur $E$, alors
    une application est dite linéaire si $$\begin{aligned}
       &f(x+y)=f(x)+f(y),\quad \forall x,y\in W,\\
       &f(\alpha \cdot x)=\alpha \cdot f(x),\quad \forall \alpha\in E,\ \mbox{et}\ x\in W.
      \end{aligned}$$

### Base

Nous avons introduit la notion très générale d’espace vectoriel et
nous avons présenté quelques exemples. Reprenons l’exemple de l’espace
Euclidien, soit l’espace des vecteurs comme vous en avez l’habitude.
Limitons nous au cas où les vecteur sont bidimensionnels, soit
$v=(v_1,v_2)$ avec $v_1,v_2\in{\real}$. D’habitude ces vecteurs
sont représentés dans le système de coordonnées cartésien où on a deux
vecteurs (de base) définis comme $e_1=(1,0)$ et $e_2=(0,1)$ qui sont
implicites. Par exemple, si $u=(4,5)$ cela signifie implicitement que 
$$u=4\cdot e_1+5\cdot e_2.$$

![Le vecteur $v$ dans la représentation
cartésienne.](figs/baseCart.svg){#fig:baseCart width="35.00000%"}

De façon générale tout vecteur $v=(v_1,v_2)$ est représenté implicitement
par (voir la @fig:baseCart) $$v=v_1\cdot e_1+v_2\cdot e_2.$$ On
dit que $e_1$ et $e_2$ forme une *base* de l’espace ${\real}^2$. En
d’autres termes n’importe quel vecteur $v\in{\real}^2$ peut être
exprimé comme une combinaison linéaire de $e_1$ et $e_2$.

Néanmoins, le choix de la base $e_1$ et $e_2$ est totalement arbitraire.
N’importe quelle autre paire de vecteurs (qui n’on pas la même
direction) peut être utilisée pour représenter un vecteur quelconque
dans le plan (voir la @fig:baseNonCart).

![Le vecteur $v$ dans une représentation non
cartésienne.](figs/baseNonCart.svg){#fig:baseNonCart width="35.00000%"}

Cette écriture en fonction de vecteurs de base, permet de faire
facilement les additions de vecteurs
$$w=u+v=u_1\cdot e_1+u_2\cdot e_2+v_1\cdot e_1+v_2\cdot e_2=(u_1+v_1)\cdot e_1+(u_2+v_2)\cdot e_2.$$

---

#### Illustration  (Exemples de bases d'espaces vectoriels) {-}

1. Pour l’espace des fonctions polynomiales $f(x)=\sum_{i=0}^Na_ix^i$
    les fonction $e_i=x^i$ forment une base.

2. Pour l’espace vectoriel des fonctions périodiques les fonctions
    $\sin$ et $\cos$ forment une base (voir plus de détails dans ce qui
    suit).

---

Plus formellement nous allons introduire un certain nombre de concepts
mathématiques pour définir une base. Considérons toujours $V$ un espace
vectoriel sur $E$.

#### Définition (Famille libre) {-}

Soient $\{\alpha_i\}_{i=1}^n\in E$. On dit qu’un ensemble de vecteurs
$\{v_i\}_{i=1}^n\in V$ est une famille libre si
$$\sum_{i=1}^n \alpha_iv_i=0 \Rightarrow \alpha_i=0,\ \forall i.$$

#### Exemple (Famille libre) {-}

1. $\{e_1\}$ est une famille libre de ${\real}^2$.

2. $\{e_1,e_2\}$ est une famille libre de ${\real}^2$.

3. $\{e_1,e_2,v\}$, avec $v=(1,1)$ n’est pas une famille libre de
    ${\real}^2$. En effet,
    $$1\cdot e_1+1\cdot e_2-1\cdot v=(0,0).$$

4. $\{\sin(x),\cos(x)\}$ est une famille libre. On ne peut pas écrire
    $\sin(x)=\alpha\cos(x)+\beta$. Il n’y a pas de relation linéaire qui
    relie les deux. La relation est non-linéaire
    $\sin(x)=\sqrt{1-\cos^2(x)}$.

#### Définition (Famille génératrice) {-}

On dit qu’un ensemble de vecteurs $\{e_i\}_{i=1}^n\in V$ est une famille
génératrice si
$$\forall\ v\in V,\quad \exists \{\alpha_i\}_{i=1}^n\in E,\quad \mbox{t.q.}\quad v=\sum_{i=1}^n\alpha_i\cdot e_i.$$
En d’autres termes, tout $v\in V$ peut s’exprimer comme une combinaison
linéaire des vecteur $e_i$.

#### Illustration (Familles génératrices) {-}

1. $\{e_1\}$ n’est pas une famille génératrice de ${\real}^2$. On ne
    peut pas représenter  les vecteurs de la forme $v=(0,v_2)$,
    $v_2\neq 0$.

2. $\{e_1,e_2\}$ est une famille génératrice de ${\real}^2$.

3. $\{e_1,e_2,v\}$, avec $v=(1,1)$ est une famille génératrice de
    ${\real}^2$.

#### Définition (Base) {-}

Un ensemble de vecteurs $B=\{e_i\}_{i=1}^n$ forme une base si c’est une
famille génératrice et une famille libre. En d’autres termes cela
signifie qu’un vecteur $v\in V$ peut se représenter comme une
combinaison linéaire de $\{e_i\}_{i=1}^n$ et que cette représentation
est unique
$$\forall v\in V, \quad !\exists \{\alpha_i\}_{i=1}^n\in E,\quad t.q.\quad v=\sum_{i=1}^n\alpha_i v_i.$$
Les $\alpha_i$ sont appelé les coordonnées de $v$ dans la base $B$.

#### Illustration (Base de $\real ^2$) {-}

1. $\{e_1,e_2\}$ est une base de ${\real}^2$.

2. $\{e_1,e_2,e_3\}$, avec $e_3=(1,1)$, n’est pas une base de
    ${\real}^2$, car ce n’est pas une famille libre. On a par
    exemple que l’élément $v=(0,0)$ peut se représenter avec les
    coordonnées $\alpha=(0,0,0)$ et également les coordonnées
    $\beta=(1,1,-1)$.

## Introduction générale sur les séries de Fourier

Dans cette sous section, nous allons voir de façon très générale les
concepts de la représentation de série de Fourier de fonctions.

### Considérations historiques

Historiquement, les séries de Fourier sont apparues lorsque les
mathématiciens/physiciens du 18-19ème siècles ont essayé de résoudre des
équations différentielles particulières. En particulier, il y avait
l’équation de la propagation d’ondes
$${\frac{\partial^2 \rho}{\partial t^2}}=\alpha^2\left({\frac{\partial^2 \rho}{\partial x^2}}+{\frac{\partial^2 \rho}{\partial y^2}}+{\frac{\partial^2 \rho}{\partial z^2}}\right),$${#eq:ondes}
où $\rho$ est l’amplitude de l’onde et $\alpha$ la vitesse de
propagation. On a également l’équation de la chaleur
$${\frac{\partial T}{\partial t}}=\kappa\left({\frac{\partial^2 T}{\partial x^2}}+{\frac{\partial^2 T}{\partial y^2}}+{\frac{\partial^2 T}{\partial z^2}}\right),$$
où $T$ est la température et $\kappa$ la diffusivité thermique.

Ces équations ont une structure particulière. En effet, d’une part elles
sont linéaires. Soient $\rho_1$ et $\rho_2$ deux solutions de l’équation
@eq:ondes, on a que la somme $\rho_1+\rho_2$ est également
solution de @eq:ondes. Cette structure d’équation différentielle
impose des contraintes assez fortes sur la forme des solutions.

Par ailleurs, le fait que les dérivées à différents ordres apparaissent
dans la même équation, cela impose que les fonctions et leurs dérivées à
différents ordres soient reliées entre elles. Les fonctions qu’on
connaît qui ont ces propriétés sont l’exponentielle et les fonctions
sinus ou cosinus. Dans le cas de propagation d’ondes, on voit qu’on a
uniquement des deuxièmes dérivées, et on en déduit que les fonctions
importantes seront des sinus et des cosinus.

On constate que le choix du sinus ou du cosinus pour représenter ces
solutions ne tombe pas du ciel. Il est dicté par les propriétés des
équations que nous tentons de résoudre. En fait, nous mettons à notre
disposition des outils mathématiques appropriés pour résoudre des
problèmes physiques existant et qui ont des contraintes particulières.

### Décomposition de signaux périodiques

Nous allons considérer une fonction $f(t)$ qui est une fonction
périodique, de période $T$, de pulsation $\omega=2\pi/T$ et de fréquence
$\nu=1/T$. La périodicité signifie que 
$$f(t+T)=f(t),\quad \forall t.$$ Nous cherchons à décomposer $f$ en un
ensemble potentiellement infini de fonctions périodiques. Notons cet
ensemble de fonctions $\{g_j\}_{j=0}^\infty$, où $g_j$ est une fonction
périodique. En fait on cherche une décomposition où pour un ensemble
unique de $\{\alpha_j\}_{j=0}^\infty$
$$f(t)=\sum_{j=0}^\infty \alpha_j g_j(t).$$ Cette décomposition nous
fait penser furieusement à une décomposition dans une base particulière,
où les $g_j$ sont les vecteurs de la base et les $\alpha_j$ sont les
coordonnées de $f$ dans la base des $g_j$.

La fonction de départ $f$ ayant une période $T$, on a obligatoirement
que les fonctions $g_j$ ont une période qui doit être une fraction
entière de la période, $T/j$. Ces fonctions $g_j(t)$ peuvent en général
avoir une forme quelconque, avec l’unique contrainte qu’elles sont
périodiques avec période $T/j$. Ça pourrait être un signal carré,
triangulaire, etc. Dans les cas qui nous intéresse, on a un choix
naturel qui s’impose comme fonctions périodiques: les sinus et cosinus.

Pour commencer, imaginons que nous voulions décomposer (approximer) $f$
en une somme de $g_j\sim A_j\sin(j\omega t+\phi_j)$. On peut jouer sur
deux degrés de libertés des sinus dont la période est imposée, soit
l’amplitude $A_j$ et la phase $\phi_j$. On va donc écrire $f(t)$ comme
$$f(t)=\sum_{j=0}^\infty A_j\sin(j\omega t+\phi_j).$${#eq:sin_phase_ampl}
Cette forme n’est pas pratique du tout comme décomposition, en
particulier à cause de la phase $\phi_j$. On utilise alors la relation
trigonométrique (déjà utilisée pour interpréter le produit de deux
nombres complexes)
$$\sin(\theta+\phi)=\sin(\theta)\cos(\phi)+\cos(\theta)\sin(\phi).$$ Il
vient  $$\begin{aligned}
 f(t)=\sum_{j=0}^\infty A_j\left(\sin(j\omega t)\cos(\phi_j)+\cos(j\omega t)\sin(\phi_j)\right).\end{aligned}$$
En renommant $$\begin{aligned}
a_j&\equiv A_j\sin(\phi_j),\\
b_j&\equiv A_j\cos(\phi_j),\end{aligned}$$ on obtient
$$f(t)=\sum_{j=0}^\infty \left(a_j\cos(j\omega t)+b_j\sin(j\omega t)\right). $${#eq:decomp_sincos}
On a ainsi transformé une équation où on devait déterminer une amplitude
et une phase, ce qui est plutôt compliqué, en une autre équation où on
doit déterminer uniquement deux amplitude. Par ailleurs, comme $\cos$ et
$\sin$ sont indépendants, on peut calculer les $a_j$ et $b_j$ de façon
également indépendantes.

Nous voulons à présent calculer $a_j$ et $b_j$ pour avoir les
coordonnées de $f$ dans la base des $\sin$ et des $\cos$. Pour ce faire,
nous allons  tenter de trouver les amplitudes $a_j,b_j$ tels que les
$a_j\cos(j\omega t)$ et $b_j\sin(j\omega t)$ approximent au mieux la
fonction $f$.

Nous allons considérer les fonctions d’erreur suivantes
$$E^s_j=\int_0^T(f(t)-b_j\sin(j\omega t))^2{\mathrm{d}}t,\quad E^c_j=\int_0^T(f(t)-a_j\cos(j\omega t))^2{\mathrm{d}}t.$$
Puis on va déterminer $a_j,b_j$ tels que $E_j^s$ et $E_j^c$ sont
minimales. Pour ce faire on va utiliser les dérivées et déterminer nos
coefficients en résolvant les équations
$${\frac{{\mathrm{d}}E^c_j}{{\mathrm{d}}a_j}}=0.$${#eq:deriv_aj}
$${\frac{{\mathrm{d}}E^s_j}{{\mathrm{d}}b_j}}=0,$${#eq:deriv_bj}
Pour l'@eq:deriv_aj, on a $$\begin{aligned}
 {\frac{{\mathrm{d}}E^c_j}{{\mathrm{d}}a_j}}&={\frac{{\mathrm{d}}\int_0^T(f(t)-a_j\cos(j\omega t))^2{\mathrm{d}}t}{{\mathrm{d}}a_j}},\nonumber\\
 &=\underbrace{{\frac{{\mathrm{d}}(\int_0^Tf^2(t){\mathrm{d}}t)}{{\mathrm{d}}a_j}}}_{=0}+{\frac{{\mathrm{d}}(a_j^2\int_0^T(\cos^2(j\omega t){\mathrm{d}}t))}{{\mathrm{d}}a_j}}-{\frac{{\mathrm{d}}(2a_j\int_0^T(f(t)\cos(j\omega t){\mathrm{d}}t))}{{\mathrm{d}}a_j}},\nonumber\\
 &=2a_j\int_0^T\cos^2(j\omega t){\mathrm{d}}t-2\int_0^Tf(t)\cos(j\omega t){\mathrm{d}}t,\nonumber\\
 &=2a_j\frac{T}{2}-2\int_0^T\cos(j\omega t)f(t){\mathrm{d}}t.\end{aligned}$$
Finalement on obtient
$$a_j=\frac{2}{T}\int_0^T\cos(j\omega t)f(t){\mathrm{d}}t.$$ Pour $a_j$
on a de façon similaire
$$b_j=\frac{2}{T}\int_0^T\sin(j\omega t)f(t){\mathrm{d}}t.$$ En
particulier si $j=0$, on a
$$b_0=0,\quad a_0=\frac{2}{T}\int_0^T f(t){\mathrm{d}}t.$$ On constate
que $b_0/2$ correspond à la valeur moyenne de $f(t)$ dans $[0,T]$. Cela
permet d’approximer des fonctions dont la valeur moyenne n’est pas nulle
(les sinus et cosinus ont toujours des moyennes nulles).

Les coefficients $a_j,b_j$ peuvent être calculés directement à partir de
$f(t)$, comme nous venons de le voir. Nous pouvons obtenir le même
résultat, en utilisant les relations suivantes (exercice)
$$\begin{aligned}
 \int_0^T \sin(k \omega t)\sin(j \omega t){\mathrm{d}}t&=\delta_{jk} \frac{T}{2},\\
 \int_0^T \cos(k \omega t)\cos(j \omega t){\mathrm{d}}t&=\delta_{jk} \frac{T}{2},\\
 \int_0^T \sin(k \omega t)\cos(j \omega t){\mathrm{d}}t&=0,\end{aligned}$$
qui s’obtiennent en utilisant les relations trigonométriques suivantes
$$\begin{aligned}
 \sin\theta\sin\phi&= \frac{1}{2}\left(\cos(\theta-\phi)-\cos(\theta+\phi)\right),\\
 \cos\theta\cos\phi&= \frac{1}{2}\left(\cos(\theta-\phi)+\cos(\theta+\phi)\right),\\
 \sin\theta\cos\phi&= \frac{1}{2}\left(\sin(\theta+\phi)+\sin(\theta-\phi)\right).\end{aligned}$$

Cela est dû à la propriété d’orthogonalité des fonctions sinus/cosinus.
En multipliant l'@eq:decomp_sincos par
$\frac{2}{T}\sin(k \omega t)$ et en intégrant entre $0$ et $T$, on
obtient $$\begin{aligned}
\frac{2}{T}\int_0^T f(t)\sin(k\omega t){\mathrm{d}}t&=\frac{2}{T}\sum_{j=0}^\infty \left(b_j\underbrace{\int_0^T\cos(j\omega t)\sin(k\omega t){\mathrm{d}}t}_{=0}+a_j\underbrace{\int_0^T\sin(j\omega t)\sin(k \omega t){\mathrm{d}}t}_{=\frac{T}{2}\delta_{jk}}\right),\nonumber\\
\frac{2}{T}\int_0^T f(t)\sin(k\omega t){\mathrm{d}}t&=\sum_{j=0}^\infty a_j \delta_{jk}=a_k,\end{aligned}$$
où $\delta_{jk}$ est le “delta de Kronecker”, dont la définition est
$$\delta_{jk}=\left\{\begin{array}{ll}
                1,&\mbox{ si }j=k\\
                0,&\mbox{ sinon.}
               \end{array}\right.$$

En multipliant l'@eq:decomp_sincos par
$\frac{2}{T}\cos(k \omega t)$ et en intégrant entre $0$ et $T$, on
obtient $$\begin{aligned}
\frac{2}{T}\int_0^T f(t)\cos(k\omega t){\mathrm{d}}t&=\frac{2}{T}\sum_{j=0}^\infty \left(a_j\underbrace{\int_0^T\cos(j\omega t)\sin(k\omega t){\mathrm{d}}t}_{=0}+b_j\underbrace{\int_0^T\cos(j\omega t)\cos(k \omega t){\mathrm{d}}t}_{=\frac{T}{2}\delta_{jk}}\right),\nonumber\\
\frac{2}{T}\int_0^T f(t)\cos(k\omega t){\mathrm{d}}t&=\sum_{j=0}^\infty b_j \delta_{jk}=b_k.\end{aligned}$$

### Les séries de Fourier en notations complexes

Comme on le voit dans l'@eq:decomp_sincos, on
décompose $f(t)$ en une somme contenant des sinus et des cosinus. Cette
écriture nous fait penser qu’il pourrait être possible de réécrire cette
somme de façon plus concise à l’aide des nombres complexes
($e^{i\theta}=\cos\theta+i\cdot\sin\theta$). Effectivement cette
réécriture est possible. Pour ce faire il faut définir de nouveaux
coefficients $c_n$, $$c_n=\left\{\begin{array}{ll}
                \frac{a_n+ib_n}{2}, & \mbox{ si }n<0\\
                \frac{a_0}{2},      & \mbox{ si }n=0\\
                \frac{a_n-ib_n}{2}, & \mbox{ si }n>0
               \end{array}\right.$$ Avec cette notation, on peut
réécrire l'@eq:decomp_sincos (exercice) comme
$$f(t)=\sum_{j=-\infty}^\infty c_je^{ij\omega t}.$$ En multipliant cette
relation par $\frac{1}{T}e^{-ik\omega t}$ et en intégrant entre
$-\frac{T}{2}$ et $\frac{T}{2}$, on obtient
$$\frac{1}{T}\int_{-\frac{T}{2}}^{\frac{T}{2}}f(t)e^{-ik\omega t}{\mathrm{d}}t=\frac{1}{T}\sum_{j=-\infty}^\infty c_j\int_{-\frac{T}{2}}^{\frac{T}{2}}e^{ij\omega t}e^{-ik\omega t}{\mathrm{d}}t.$$
Pour évaluer le membre de droite de cette équation nous transformons les
exponentielles en sinus/cosinus. L’intégrale du membre de droite devient
$$\begin{aligned}
\int_{-\frac{T}{2}}^{\frac{T}{2}}e^{ij\omega t}e^{-ik\omega t}{\mathrm{d}}t&=\int_{-\frac{T}{2}}^{\frac{T}{2}}\left(\cos(j\omega t)+i\sin(j\omega t)\right)\left(\cos(-k\omega t)+i\sin(-k\omega t)\right){\mathrm{d}}t,\nonumber\\
&=\int_{-\frac{T}{2}}^{\frac{T}{2}}\left(\cos(j\omega t)\cos(k\omega t)+\sin(j\omega t)\sin(k\omega t)\right.\nonumber\\
&\quad\quad\left.-i(\cos(j\omega t)\sin(k\omega t)+\cos(k\omega t)\sin(j\omega t))\right){\mathrm{d}}t,\nonumber\\
&=T\delta_{jk}.\end{aligned}$$ En remplaçant cette relation dans
l’équation ci-dessus[^6], on a
$$\frac{1}{T}\int_{-\frac{T}{2}}^{\frac{T}{2}}f(t)e^{-ik\omega t}{\mathrm{d}}t=\sum_{j=-\infty}^\infty c_j\delta_{jk}=c_k.$${#eq:ck}
Cette relation nous dit comment évaluer les coefficients $c_k$ de la
série de Fourier de $f(t)$.

On notera que pour une fonction périodique, on obtient des coefficients
de la série de Fourier qui sont discrets.

La série de Fourier pour une fonction quelconque: la transformée de Fourier
---------------------------------------------------------------------------

Il est possible d’écrire de telles séries pour des fonctions
non-périodiques. Pour ce faire, il faut prendre la limite
$T\rightarrow\infty$. Pour ce faire on va écrire
$$f(t)=\sum_{j=-\infty}^\infty c_je^{ij\omega t},$$ où on remplace le
coefficient $c_j$ par l'@eq:ck. On obtient
$$f(t)=\sum_{j=-\infty}^\infty \left(\frac{1}{T}\int_{-\frac{T}{2}}^{\frac{T}{2}}f(t)e^{-ij\omega t}{\mathrm{d}}t\right) e^{ij\omega t}.$$
En utilisant la relation
$$\frac{1}{T}=\frac{\omega}{2\pi}=\frac{\omega(j-j+1)}{2\pi}=\frac{\omega(j+1)}{2\pi}-\frac{\omega j}{2\pi},$$
ainsi que la notation $\omega_j=j\omega$, on peut réécrire cette
équation $$\begin{aligned}
 f(t)&=\sum_{j=-\infty}^\infty \frac{1}{2\pi}(\omega_{j+1}-\omega_j)\underbrace{\left(\int_{-\frac{\pi}{\Delta \omega_j}}^{\frac{\pi}{\Delta \omega_j}}f(t)e^{-i\omega_j t}{\mathrm{d}}t\right)}_{\equiv {\hat{f}}(\omega_j)} e^{i\omega_j t},\nonumber\\
     &=\frac{1}{2\pi}\sum_{j=-\infty}^\infty (\Delta \omega_j){\hat{f}}(\omega_j) e^{i\omega_j t}.\end{aligned}$$
Maintenant pour passer dans le cas où la fonction n’est pas périodique
(la période est infinie), nous devons prendre la limite
$\Delta \omega_j\rightarrow 0$ dans l’équation précédente, et on voit
apparaître une somme de Riemann $$\begin{aligned}
 f(t)&=\frac{1}{2\pi}\sum_{j=-\infty}^\infty \lim\limits_{\Delta \omega_j\rightarrow 0}\Delta \omega_j{\hat{f}}(\omega_j) e^{i\omega_j t},\nonumber\\
 &=\frac{1}{2\pi}\int_{-\infty}^\infty {\hat{f}}(\omega) e^{i\omega t}{\mathrm{d}}\omega.\end{aligned}$$
A présent, nous avons deux opérateurs que nous allons nommer. Nous avons
la transformée de Fourier
$${\hat{f}}(\omega)=\int_{-\infty}^{\infty}f(t)e^{-i\omega t}{\mathrm{d}}t,$${#eq:fourier_transform}
et la transformée de Fourier inverse
$$f(t)=\frac{1}{2\pi}\int_{-\infty}^\infty {\hat{f}}(\omega) e^{i\omega t}{\mathrm{d}}\omega.$${#eq:inverse_fourier_transform}
On a immédiatement qu’appliquer la transformée de Fourier et la
transformée de Fourier inverse sur une fonction $f(t)$, nous donne la
fonction originale $f(t)$.

La fonction $f(t)$ doit satisfaire un certain nombre de contraintes pour
pouvoir calculer sa transformée de Fourier:

1. Elle doit être de carré intégrable
    $$\int_{-\infty}^\infty |f(t)|^2{\mathrm{d}}t < \infty$$

2. Elle doit avoir un nombre fini d’extrema (ne doit pas varier trop
    vite).

3. Elle doit avoir un nombre fini de discontinuités.

---

#### Exercice {-}

Calculer les transformées de Fourier des fonctions suivantes

1. Le pulse symétrique $$f(t)=\left\{\begin{array}{ll}
                    1,&\mbox{ si }-t_c<t<t_c\\
                    0,&\mbox{ sinon.}
                   \end{array}\right.$$
2. Le pulse asymétrique $$f(t)=\left\{\begin{array}{ll}
                    1,&\mbox{ si } 0<t<2t_c\\
                    0,&\mbox{ sinon.}
                   \end{array}\right.$$
3. L’exponentielle décroissante $$f(t)=\left\{\begin{array}{ll}
                    e^{-at},&\mbox{ si } t>0\\
                    0,&\mbox{ sinon.}
                   \end{array}\right.$$

---

---

#### Exercice {-}

Calculer les transformées de Fourier inverse de la fonction suivante

1. Le pulse symétrique $$f(\omega)=\left\{\begin{array}{ll}
                    1,&\mbox{ si }-\omega_c<\omega<\omega_c\\
                    0,&\mbox{ sinon.}
                   \end{array}\right.$$

---

## Propriétés des transformées de Fourier

La transformée de Fourier possède plusieurs propriétés intéressantes.

#### Propriété {-}

1. Linéarité. Soit une fonction $h(t)=af(t)+bg(t)$, alors sa
    transformée de Fourier est donnée par
    $${\hat{h}}(\omega)=a{\hat{f}}(\omega)+b{\hat{g}}(\omega).$$

2. Translation temporelle. Soit une fonction $g(t)=f(t+t_0)$, alors sa
    transformée de Fourier est donnée par
    $${\hat{g}}(\omega)={\hat{f}}(\omega)e^{i\omega t_0}.$$

3. Modulation en fréquence. Soit $\omega_0\in{\real}$ et une
    fonction $g(t)=e^{-i\omega_0 t}f(t)$, alors sa transformée de
    Fourier est donnée par
    $${\hat{g}}(\omega)={\hat{f}}(\omega+\omega_0).$$

4. Contraction temporelle. Soit $a\in{\real}^\ast$ et $g(t)=f(at)$
    alors sa transformée de Fourier est donnée par
    $${\hat{g}}(\omega)=\frac{1}{|a|}{\hat{f}}(\omega/a).$$ En
    particulier, on a la propriété d’inversion du temps quand $a=-1$, on
    a $h(t)=f(-t)\Rightarrow{\hat{h}}(\omega)={\hat{f}}(-\omega)$.

5. Spectres de fonctions paires/impaires. Soit $f(t)$ une fonction
    paire (impaire), alors ${\hat{f}}(\omega)$ sera une fonction paire
    (impaire).

La transformée de Fourier à temps discret (TFTD)
------------------------------------------------

Nous allons maintenant plus considérer une fonction continue, mais une
série de valeurs discrètes. Notons $f[n]$ une série de nombres, avec
$n\in{\mathbb{N}}$. Nous voulons définir l’équivalent de la transformée
de Fourier de l'@eq:fourier_transform pour ce genre de
séries de points. Une façon naturelle de définir l’équivalent à temps
discret de cette équation est
$${\hat{f}}(\omega)=\sum_{n=-\infty}^\infty f[n] e^{-i\omega n}.$${#eq:tftd}
Pour les fonctions à "temps continu" et non périodiques, nous
savons que la transformée de Fourier est continue et en général non
périodique. Pour le cas de la transformée de Fourier à temps discret la
transformée de Fourier sera périodique, soit
$${\hat{f}}(\omega+2\pi)={\hat{f}}(\omega).$$ Nous démontrons cette
relation par la définition de la TFTD
$${\hat{f}}(\omega+2\pi)=\sum_{n=-\infty}^\infty f[n] e^{-i(\omega+2\pi) n}=\underbrace{e^{-i2\pi}}_{=1}\sum_{n=-\infty}^\infty f[n] e^{-i\omega n}={\hat{f}}(\omega).$$
D’une certaine façon nous voyons que nous avons une similarité entre la
transformée de Fourier à temps discret et les séries de Fourier. Cette
similarité va devenir plus claire dans ce qui suit.

Pour définir la transformée de Fourier en temps discret inverse, nous
nous inspirons de la version en temps continu (voir l’équation
@eq:inverse_fourier_transform) et on a
$$f[n]=\frac{1}{2\pi}\int_{-\pi}^\pi{\hat{f}}(\omega)e^{i\omega n}{\mathrm{d}}\omega. $${#eq:tftdi}
Pour prouver cette relation, il suffit de remplacer l’équation
@eq:tftd dans cette relation, et il vient
$$f[n]=\frac{1}{2\pi}\int_{-\pi}^\pi \left(\sum_{m=-\infty}^\infty f[m] e^{-i\omega m}\right) e^{i\omega n}{\mathrm{d}}\omega.$$
En supposant que la somme converge, nous pouvons intervertir la somme et
l’intégrale et on a $$\begin{aligned}
 f[n]&=\frac{1}{2\pi}\left(\sum_{m=-\infty}^\infty f[m] \int_{-\pi}^\pi e^{-i\omega (m-n)} {\mathrm{d}}\omega\right),\nonumber\\
     &=\frac{1}{2\pi}\left(\sum_{m=-\infty}^\infty f[m] \delta_{mn} 2\pi\right),\nonumber\\
     &=f[n].\nonumber\end{aligned}$$


#### Exercice  {-}

Calculer les transformées de Fourier (inverses quand c’est approprié) en
temps discret des fonctions suivantes

1. Le pulse symétrique $${\hat{f}}(\omega)=\left\{\begin{array}{ll}
                    1,&\mbox{ si }-\omega_c<\omega<\omega_c\\
                    0,&\mbox{ sinon.}
                   \end{array}\right.$$

2. Le pulse discret $$f[n]=\left\{\begin{array}{ll}
                    1,&\mbox{ si }n=0\\
                    0,&\mbox{ sinon.}
                   \end{array}\right.$$

Il est intéressant de noter qu’on peut représenter une suite discrète et
infinie de points par une fonction continue et périodique.

La transformée de Fourier discrète
----------------------------------

### Motivation

Pourquoi avons-nous besoin d’encore une transformée de Fourier? Nous
avons déjà vu la transformée de Fourier de fonctions périodiques, de
fonctions non-périodiques, ainsi que de fonctions à temps discret.
Néanmoins, même dans le cas de la transformée de Fourier à temps
discret, la transformée de Fourier est une fonction continue. Cela n’est
évidemment pas pratique ni même utilisable dans un ordinateur. C’est
pourquoi il est nécessaire de définir une transformée de Fourier
discrète qui aura les propriétés suivantes

1. Elle transformera un signal discret de longueur finie.

2. La transformée de Fourier sera discrète et de longueur finie.

### Applications

Avant de voir en détail comment on calcule la transformée de Fourier
discrète, on peut discuter quelle sont ses applications. La TFD est
utilisée tout le temps en traitement du signal. En gros c’est une
approximation de la transformée de Fourier à temps discret. A chaque
fois qu’on désire connaître le comportement d’une fonction dans l’espace
spectral, on utilisera la TFD. Un exemple typique est l’application pour
téléphones portables Shazam que vous connaissez sans doute. Le but de
cette application est l’identification de chansons. Elle fonctionne de
la façon suivante. Dans un premier temps elle enregistre un signal
sonore. Puis avec ce signal sonore elle crée un spectrogramme (une sorte
d’emprunte digitale de la chanson) qui est obtenu à l’aide de TFD.
Finalement le spectrogramme est comparé avec une base de donnée de
spectrogrammes et la chanson peut ainsi être identifiée. Une autre
application est le filtrage de signaux. Comme vous l’avez vu (ou verrez)
dans les travaux pratiques, la TFD rend très simple le filtrage de
fréquences (ou de bande de fréquences). En effet, il suffit d’ôter de la
TFD d’un signal les amplitudes voulues et d’effectuer la transformée de
Fourier discrète inverse (TFDI) du signal filtré. Ce genre
d’applications est très utilisé dans le domaine de la compression de
données (jpg, mp3, ...).

### La transformée de Fourier discrète à proprement parler

Soit $f[n]$ un séquence de $N$ points, $n=0..N-1$. Pour se
ramener au cas de la transformée de Fourier à temps discret, on peut
aussi se dire qu’on a une séquence infinie de points, mais où $f[n]=0$,
pour $n\geq N$. On dit qu’on a $N$ échantillons de $f$.

Avec cette définition il est simple de calculer la transformée de
Fourier à temps discret
$${\hat{f}}(\omega)=\sum_{n=0}^{N-1} f[n] e^{-i\omega n}.$${#eq:tftd_fini}
On note que la somme à présent ne se fait plus dans l’intervalle
$(-\infty,\infty)$, mais uniquement entre $[0,N-1]$, car le signal est
de longueur finie.

On représente donc un signal de longueur finie $f[n]$ ($n=0,..,N-1$) par
une fonction continue de la pulsation, ${\hat{f}}(\omega)$. Les deux
représentations sont équivalentes. On en déduit que l’information
contenue dans un nombre fini de points, est la même que dans une
fonction continue (et donc contenant une infinité de points). Une partie
de l’information contenue dans la fonction continue doit être
redondante...

L’idée à présent va être d’enlever toute l’information redondante de
${\hat{f}}(\omega)$ en échantillonnant ${\hat{f}}$ et en gardant
uniquement $N$ échantillons de ${\hat{f}}$. La fréquence
d’échantillonnage sera de $2\pi/N$ et le domaine d’échantillonnage sera
$[-\pi,\pi)$.

Nous pouvons à présent définir mathématiquement cet échantillonnage de
${\hat{f}}(\omega)$ comme étant une suite de points, notée
$\{{\hat{f}}(\omega_k)\}_{k=0}^{N-1}$, où $\omega_k=2\pi k/N$. Cette
suite sera notée ${\hat{f}}[k]$ et appelée la *transformée de Fourier
discrète* de $f[n]$.

On a donc que la transformée de Fourier discrète de $f[n]$ est donnée
par $${\hat{f}}[k]=\sum_{n=0}^{N-1} f[n] e^{-i\omega_k n}
       =\sum_{n=0}^{N-1} f[n] e^{-\frac{2\pi i n k}{N}}.$${#eq:tfd}
En s’inspirant de définition de la transformée de Fourier inverse à
temps discret de ${\hat{f}}(\omega)$ (voir l’équation
@eq:tftdi), on a que la transformée de Fourier discrète inverse
est donnée par
$$f[n]=\frac{1}{N}\sum_{k=0}^{N-1} {\hat{f}}[k] e^{i\omega_k n}
 =\frac{1}{N}\sum_{k=0}^{N-1} {\hat{f}}[k] e^{\frac{2\pi i k n}{N}}.$$
Montrons à présent que la transformée inverse discrète de la transformée
de Fourier discrète donne bien la suite de départ $$\begin{aligned}
 f[n]&=\frac{1}{N}\sum_{k=0}^{N-1} {\hat{f}}[k] e^{\frac{2\pi i k n}{N}},\nonumber\\
 &=\frac{1}{N}\sum_{k=0}^{N-1} \sum_{m=0}^{N-1} f[m] e^{-\frac{2\pi i k m}{N}} e^{\frac{2\pi i k n}{N}},\nonumber\\
 &=\frac{1}{N}\sum_{k=0}^{N-1} \sum_{m=0}^{N-1} f[m] e^{\frac{2\pi i k (n-m)}{N}},\nonumber\\
 &=\frac{1}{N}\sum_{m=0}^{N-1} f[m] \sum_{k=0}^{N-1} e^{\frac{2\pi i k (n-m)}{N}},\nonumber\\
 &=\frac{1}{N}\sum_{m=0}^{N-1} f[m] N \delta_{nm},\nonumber\\
 &=f[n].\end{aligned}$$ Cette relation montre qu’on a bien la même
information dans la suite de longueur finie ${\hat{f}}[k]$ que dans
$f[n]$. On a donc enlevé avec succès toute information redondante
contenue dans ${\hat{f}}(\omega)$.

On peut maintenant de façon simple implémenter la transformée de Fourier
discrète sur un ordinateur car on a discrétisé toutes les étapes du
calcul. Néanmoins les formules ci-dessus ne sont pas d’une grande
efficacité. En effet, on peut montrer que la complexité de l’équation
@eq:tfd est de l’ordre $N^2$.

On peut écrire l'@eq:tfd comme un produit
matrice-vecteur sous la forme suivante
$$
\begin{array}{l} 
    \underbrace{
        \begin{pmatrix} {\hat{f}}[0] \\ {\hat{f}}[1] \\ f[2] \\ \vdots \\ {\hat{f}}[N-1] 
        \end{pmatrix}
    }_{\hat{\vec{f}}} = 
    \underbrace{
        \begin{pmatrix} 1 & 1 & 1 & \cdots & 1\\ 
                        1 & w & w^2 & \cdots & w^{N-1}\\ 
                        1 & w^2 & w^4 & \cdots & w^{2(N-1)}\\ 
                        \vdots & \vdots & \vdots & \ddots & \vdots &\\ 
                        1 & w^{N-1} & w^{2(N-1)} & \cdots & w^{(N-1)^2}
        \end{pmatrix}}_{\underline{\underline{W}}}\cdot 
\end{array} 
\underbrace{
\begin{pmatrix} 
f[0] \\ f[1] \\ f[2] \\ \vdots \\ f[N-1] 
\end{pmatrix}}_{\vec{f}},
$$
où $w = e^{-\frac{2 \pi i}{N}}$. On peut donc de façon plus compacte
l’écrire 
$$
\hat{\vec{f}}=\underline{\underline{W}}\cdot \vec{f}.
$$
Les éléments de la matrice
$\underline{\underline{W}}$ peuvent être précalculés et il reste donc à calculer uniquement
le produit matrice vecteur $\underline{\underline{W}}\cdot\vec{f}$. Pour ce faire il faut
pour chaque ligne de $\hat{\vec{f}}$ faire le calcul de $N$ produits et
$N$ sommes (donc une complexité $N$). Comme il y a $N$ lignes à
$\hat{\vec{f}}$, la complexité est $N\cdot N$.

Il existe des algorithmes beaucoup plus efficaces pour effectuer de
genre de calculs que nous allons brièvement discuter maintenant. Ils
réduisent la complexité algorithmique à $N\log(N)$ en général. Nous
allons brièvement discuter un de ces algorithmes dans la sous-section
@sec:tfr.

La transformée de Fourier discrète étant un échantillonnage de la
transformée de Fourier à temps discret, toutes les propriétés discutées
pour la transformée de Fourier à temps discret restent valides. En
particulier la transformée de Fourier discrète est périodique, de
période $N$ $${\hat{f}}[k]={\hat{f}}[k+N].$$ 

---

#### Exercice {-}

A démontrer en exercice.

---

### La transformée de Fourier rapide {#sec:tfr}

L’algorithme présenté ici est une version “simplifiée” de l’algorithme
de Cooley-Tukey (publié en 1965). Cet algorithme a en fait été “inventé”
par Gauss en 1805 quand il essayait d’interpoler la trajectoires
d’astéroïdes dans le système solaire.

L’idée de l’algorithme radix-2 est d’abord de séparer le signal en deux
parties. D’une part les indices pairs et d’autres part les indices
impairs $$\begin{aligned}
 &\left\{f[2m]\right\}_{m=0}^{N/2-1}=\left\{f[0],f[2],...,f[N-2]\right\},\\
 &\left\{f[2m+1]\right\}_{m=0}^{N/2-1}=\left\{f[1],f[3],...,f[N-1]\right\}.\end{aligned}$$
Puis les transformées de Fourier discrètes de chacune de ces sous-suites
sont calculées et combinées pour avoir la transformée de Fourier du
signal en entier. En fait on va appliquer cette décomposition de façon
récursive sur chacune des deux parties. On fait donc l’hypothèse que la
longueur du signal est une puissance de 2. Ce n’est en pratique pas un
problème, car on peut facilement rajouter des “zéros” dans notre signal
pour avoir un signal d’une longueur d’une puissance de 2.

Commençons donc par réécrire la transformée de Fourier ${\hat{f}}[k]$
lorsqu’on a décomposé le signal en deux sous-signaux $$\begin{aligned}
 f[k]&=\sum_{m=0}^{N/2-1} f[2m]e^{-\frac{2\pi i (2m) k}{N}}+\sum_{m=0}^{N/2-1}
 f[2m+1]e^{-\frac{2\pi i (2m+1) k}{N}},\nonumber\\
 &=\sum_{m=0}^{N/2-1} f[2m]e^{-\frac{2\pi i m k}{N/2}}+e^{-\frac{2\pi i k}{N}}\sum_{m=0}^{N/2-1} f[2m+1]e^{-\frac{2\pi i m k}{N/2}},\nonumber\\
 &=\hat{p}[k]+e^{-\frac{2\pi i k}{N}}\hat{j}[k],\end{aligned}$$ où nous
avons défini les transformées de Fourier discrètes des parties paires et
impaires $p[k]$ et $\hat{j}[k]$ $$\begin{aligned}
 \hat{p}[k]&=\sum_{m=0}^{N/2-1} f[2m]e^{-\frac{2\pi i m k}{N/2}},\\
 \hat{j}[k]&=\sum_{m=0}^{N/2-1} f[2m+1]e^{-\frac{2\pi i m k}{N/2}}.\end{aligned}$$
La transformée de Fourier discrète étant périodique (comme l’est la
transformée de Fourier à temps discret), nous avons les propriétés
suivantes $$\begin{aligned}
 \hat{p}[k]&=\hat{p}[k+N/2],\\
 \hat{j}[k]&=\hat{j}[k+N/2].\end{aligned}$$ De plus, nous avons que
$$e^{-\frac{2\pi i (k+N/2)}{N}}=e^{-\pi i}e^{-\frac{2\pi i k}{N}}=-e^{-\frac{2\pi i k}{N}}.$$
Avec ces propriétés il est aisé de réécrire
$${\hat{f}}[k]=\left\{\begin{array}{ll}
                \hat{p}[k]+e^{-\frac{2\pi i k}{N}} \hat{j}[k],&\mbox{ si }0\leq k<N/2\\
                \hat{p}[k]-e^{-\frac{2\pi i k}{N}} \hat{j}[k],&\mbox{ si }N/2\leq k<N
               \end{array}\right.$$ On a donc réduit le nombre de
calculs nécessaires pour calculer ${\hat{f}}[k]$ d’un facteur 2. En
continuant cette procédure jusqu’à $N=2$ on peut montrer qu’on réduit la
complexité algorithmique à $N\log N$ (mais on ne le démontrera pas dans
ce cours).

### Fréquence d’échantillonnage

Une question primordiale dans le calcul des transformée de Fourier (ou
de l’analyse spectrale plus généralement) est la question de
l’échantillonnage du signal que nous souhaitons analyser. Dans le monde
réel un signal sonore, une image,... est considéré comme une quantité
continue (il est représentée par une infinité de valeur). Lorsque nous
souhaitons faire une analyse spectrale sur un ordinateur de ce signal,
il est nécessaire de le digitaliser: de le rendre discret. Dès lors une
question très importante est de savoir quelle est la fréquence à
laquelle on va enregistrer les valeurs de notre suite temporelle afin de
garder toute l’information contenue dans le signal original.

En termes mathématiques, nous avons un signal $f(t)$ que nous
enregistrons entre $t_0$ et $t_{N-1}$. Nous voulons le transformer en un
signal de longueur $N$ finie, $f(t_n)$ avec $0\leq n \leq N-1$ afin de
pouvoir le représenter sur un support numérique. Pour simplifier on va
supposer que l’enregistrement se fait à intervalle régulier,
$\delta t=\frac{t_{N-1}-t_0}{N-1}$. On a donc que $t_n=t_0+\delta t n$.
La question qu’on se pose est quelle doit être la valeur de $N$ pour ne
pas perdre d’information sur $f(t)$ quand on échantillonne. En d’autres
termes à partir de quel nombre $N$ d’échantillons la transformée de
Fourier discrète de $f[n]$ ne change plus.

Le théorème de Shannon-Nyquist nous dit que pour pouvoir représenter
exactement un signal avec une fréquence maximale $F_c=1/\delta t_c$,
alors on doit l’échantillonner avec une fréquence
$1/\delta t_e=F_e\geq 2F_c$. De façon similaire, si on choisit un signal
et qu’on peut l’échantillonner avec une certaine précision (on détermine
la fréquence maximale, $F_c$ qu’on veut pouvoir représenter dans le
signal) on a simplement besoin de choisir une fréquence d’échantillonnage
$F_e\geq 2F_c$. Nous notons $F_N=2F_c$ la fréquence de Nyquist. En
prenant $F_e=F_N$ on a que $N=1/F_e=1/F_N$ et que l’échantillonnage
permet de représenter les fréquences plus petites que $F_N/2$. Si la
fréquence d’échantillonnage est plus petite que la fréquence de Nyquist
de notre signal, on verra apparaître le phénomène de *repliement de
spectre* (aliasing en anglais).
