# Probabilités et statistiques

## Introduction à la statistique descriptive

En statistique, une *population* est un ensemble d’objets (d’individus)
possédant un ou plusieurs *caractères* communs. L’étude des caractères
d’une population a pour but de révéler des tendances au sein de la
population. Ces études sont particulièrement intéressantes quand le
nombre d’individus de notre population est trop élevé pour pouvoir être
analysé en entier. On prélève alors un échantillon "représentatif" de
notre population au hasard et on mène l’analyse statistique sur ce sous
ensemble. Les éventuelles conclusions de l’étude statistique sur
le sous ensemble seront ensuite appliquées à l’ensemble de la population.
Grâce au calcul des probabilités nous pourrons  avoir une confiance
plus ou moins grande dans les conclusions tirées en fonction de la
taille de l’échantillon. En effet plus celui-ci sera grand, plus la
confiance dans les résultats sera élevée.

Un exemple de ce genre d’étude qui est très à la mode ces temps est le
sondage (concernant le résultat d’élections ou de votations). Les
sondeurs tentent en questionnant un sous-ensemble d’environ 1000
d’électeurs d’un pays (citoyens de plus de 18, moitié d’hommes et de
femmes plus ou moins, ...) de prévoir les résultats d’élections ou de
votations où participeront des millions d’électeurs potentiels. Il faut
avouer que la tâche semble pour le moins complexe. Et la plus grande
difficulté tient dans le “représentatif de la population”.

### Représentations

Il existe différentes façon de représenter les caractères d’une
population selon que sa nature est *discrète* ou *continue*. Dans le cas
discret d’un caractère pouvant prendre $k\in{\mathbb{N}}$ valeur
différentes $\{x_i\}_{i=0}^{k-1}$, on représente le nombre d’individus
pouvant prendre la valeur $x_i$ par le nombre $n_i$. On a donc un
ensemble $\{n_i\}_{i=0}^{k-1}$ d’individus pour les $k$ valeurs des
caractères de la population. Dans le cas continu le nombre d’individus
d’un caractère correspondrait à une subdivision en $k$ parties de
l’ensemble des valeurs possibles pour le dit caractère.

---

#### Illustration {-}

1. Cas discret: On étudie la distribution de salaires annuels dans une
    entreprise. Les salaires possibles sont $40'000$, $50'000$, $60'000$
    et $1'000'000$ CHF.

    - Il y a 35 personnes payées $40'000$ CHF.

    - Il y a 20 personnes payées $50'000$ CHF.

    - Il y a 5 personnes payées $60'000$ CHF.

    - Il y a 1 personne payée $1'000'000$ CHF.

2. Cas continu: Lors du benchmark d’une application, $A$, nous
    effectuons plusieurs mesures (la population) du temps d’exécution
    (le caractère) de l’application. Les résultats obtenus sont les
    suivants:

    - 7 exécutions ont pris entre 50 et 51 secondes.

    - 12 exécutions ont pris entre 51 et 52 secondes.

    - 8 exécutions ont pris entre 52 et 53 secondes.

    - 23 exécutions ont pris entre 53 et 54 secondes.

---

Pour représenter de façon un peu plus parlante ces valeurs, deux
méthodes principales existent: le tableau ou le graphique. Pour
illustrer les exemples précédents sous forme de tableau on obtient pour
le cas des salaires (voir Tabl. @tbl:salaires)

   Salaire   Nombre de salariés
  --------- --------------------
    40000            35
    50000            20
    60000            5
   1000000           1

  : Tableau du nombre de salariés par salaire. {#tbl:salaires}

et du benchmark de l’application (voir Tabl. @tbl:exec)

    Temps d’exécution     Nombre
   ------------------- --------
        \[50,51)             7
        \[51,52)            12
        \[52,53)             8
        \[53,54)            23

  : Tableau du temps d'exécution et du nombre d'exécutions. {#tbl:exec}

Sous forme de graphique on peut représenter le tableau des salaires sous
la forme d’un graphique bâton (voir Fig. @fig:salaires)

![Nombre salariés en fonction du
salaire.](figs/graph_salaires.svg){#fig:salaires width="50.00000%"}

ou d’un histogramme pour le temps d’exécution de l’application (voir
Fig. @fig:exec).

![Nombre d’exécutions en fonction du temps
d’exécution.](figs/graph_exec.svg){#fig:exec width="50.00000%"}

### Fréquences

Plutôt que de faire apparaître le nombre d’individus d’une population
possédant un caractère, il peut être plus intéressant  de
faire intervenir la *fréquence* ou le nombre relatif à la place. En
effet, la fréquence donne immédiatement la proportion d’individus plutôt
qu’un nombre absolu qui n’est pas forcément très interprétable tout
seul.

La population totale, $n$, est donnée par $$n=\sum_{i=0}^{k-1}n_i.$$ On
peut donc définir la fréquence d’un caractère $i$, $f_i$ comme
$$f_i=\frac{n_i}{n}.$$

---

#### Exemple (Fréquences) {-}

Les tableaux de fréquence des deux exemples précédents sont donnés par

1. Cas discret: la population totale est de $$n=35+20+5+1=61.$$

       Salaire   Nombre de salariés        Fréquence
      --------- -------------------- ----------------------
        40000            35           $35/61\cong0.573770$
        50000            20           $20/61\cong0.327869$
        60000            5            $5/61\cong0.081967$
       1000000           1            $1/61\cong0.016393$

      : Tableau des salaires, du nombre de salariés et la fréquence.

2. Cas continu: la population totale est de $$n=7+12+8+23=50.$$ Le
    tableau @tbl:exec_freq affiche les différentes fréquences des
    temps d’exécution.

       Temps d’exécution   Nombre     Fréquence
      ------------------- -------- --------------
           \[50,51)          7      $7/50=0.14$
           \[51,52)         12      $12/50=0.24$
           \[52,53)          8      $8/50=0.16$
           \[53,54)         23      $23/50=0.46$

      : Tableau des temps d'exécution et la fréquence des temps d'exécution. {#tbl:exec_freq}

---

La fréquence possède un certain nombre de propriétés que nous
retrouverons dans les sections suivantes qui sont assez intuitives

---

#### Propriété (Propriétés de la fréquence) {-}

1. Les fréquences sont toujours dans l’intervalle $[0,1]$
    $$0\leq f_i\leq 1.$$

2. La somme de toutes les fréquences donne toujours $1$
    $$\sum_{i=0}^{k-1} f_i = 1.$$

---

Relié avec la propriété $2$ ci-dessus, il peut également être
intéressant d’obtenir la *fréquence cumulée*, notée $F(x)$, d’un
caractère qui se définit comme la fréquence des individus qui présentent
une valeur de caractère $x_i\leq x$. Les tableaux correspondants aux
tableaux @tbl:salaires et @tbl:exec (voir le 
@tbl:salaires_freqcum et le @tbl:exec_freqcum)

   Salaire   Nombre de salariés        Fréquence             Fréquence cumulée
  --------- -------------------- ---------------------- ----------------------------
    40000            35           $35/61\cong0.573770$      $35/61\cong0.573770$
    50000            20           $20/61\cong0.327869$    $(20+35)/61\cong0.90164$
    60000            5            $5/61\cong0.081967$    $(20+35+5)/61\cong0.98361$
   1000000           1            $1/61\cong0.016393$        $(20+35+5+1)/61=1$

  : Tableau des salaires, du nombre de salariés, et la fréquence et fréquence cumulée des salaires. {#tbl:salaires_freqcum}

   Temps d’exécution   Nombre     Fréquence        Fréquence cumulée
  ------------------- -------- ---------------- ----------------------
     \[50,51)             7       $7/50=0.14$            $7/50=0.14$
     \[51,52)            12      $12/50=0.24$       $(7+12)/50=0.38$
     \[52,53)             8       $8/50=0.16$     $(7+12+8)/50=0.54$
     \[53,54)            23      $23/50=0.46$     $(7+12+8+23)/50=1$

  : Tableau des temps d'exécution et la fréquence et fréquences cumulées des temps d'exécution. {#tbl:exec_freqcum}

#### Exercice (Fréquence cumulée) {-}

1. Tracer les graphes de la fréquence cumulée pour les deux exemples
    que nous avons vus.

2. Que pouvons-nous déduire de la forme de la fonction (croissance,
    valeur maximale)?

### Mesures de tendance centrale

Jusqu’ici le nombre de valeurs étudiées était limité et il est assez
simple d’avoir une vue d’ensemble de la distribution des valeurs des
caractères de notre population. Mais en général il est plus aisé d’utiliser une nombre
de valeurs beaucoup plus restreint permettant de résumer les différents
caractères et nous allons en voir deux différents qui nous donne une
tendance dite centrale: la moyenne, la médiane.

La *moyenne*, notée $\bar{x}$ d’un jeu de données s’obtient par la
formule suivante $$\bar{x}=\frac{1}{n}\sum_{i=0}^{k-1}x_i\cdot n_i.$$ La
moyenne peut également être calculée via les fréquences
$$\bar{x}=\sum_{i=0}^{k-1}f_i\cdot x_i.$$

---

#### Exercice (Propriétés de la moyenne) {-}

1. Démontrer la relation précédente.

2. Démontrer que la moyenne des écart $x_i-\bar{x}$ est nulle.

---

---

#### Illustration (Moyenne) {-}

Pour l’exemple des salaires la moyenne est donnée par
$$\bar{x}_{\textrm{salaire}}=\frac{35\cdot40000+20\cdot50000+5\cdot60000+1\cdot1000000}{61}=60656.$$

---

On remarque ici que la moyenne des salaires donne une impression erronée
de la situation car elle est très sensible aux valeurs extrême de la
distribution. En effet, tous les salaires à l’exception d’un sont
inférieurs à la moyenne. Il suffit  de retirer le salaire d’un million
de notre ensemble de valeurs, la moyenne de l’échantillon restant
devient
$$\bar{x}_{\textrm{salaire}}=\frac{35\cdot40000+20\cdot50000+5\cdot60000}{60}=45000.$$
La différence est de l’ordre de $25\%$ par rapport aux $60'000$ CHF
obtenus avec toute la population. Il est donc nécessaire d’utiliser une
autre mesure pour illustrer mieux le salaire caractéristique de notre
population. De façon plus générale la moyenne est peu robuste à des
valeurs extrêmes dans l’étude d’échantillons.

Une mesure qui est plus parlante est la *médiane*, notée $\tilde{x}$. La
médiane se définit comme la valeur $\tilde{x}$ qui est telle que la
moitié des individus de la population ont un $x_i\leq \tilde{x}$ et
le reste est telle que $x_i\geq\tilde{x}$.

Pour l’exemple des salaires le salaire médian est de $40000 CHF$, ce qui
reflète beaucoup mieux la distribution des salaire de notre population.

#### Exercice (Moyenne, médiane) {-}

Calculer la moyenne et la médiane pour l’exemple du temps d’exécution
(prendre la borne inférieure des intervalles pour chaque temps
d’exécution[^7]).

### Mesures de dispersion

Nous avons vu deux mesures donnant une tendance générale des caractères
d’une population. Hors ces valeurs ne nous disent absolument rien sur la
manière dont ces caractères sont distribués. Sont-ils proches de la
moyenne ou de la médiane? Ou en sont-ils au contraire éloignés? Nous
allons voir deux mesures différentes dans cette sous-section: la
variance (écart-type), et l’intervalle inter-quartile.

Nous cherchons d’abord à calculer la moyenne des écarts à la moyenne.
Hors, comme on l’a vu dans la sous-section précédente l’écart à la
moyenne $x_i-\bar{x}$ est nul en moyenne. Cette grandeurs ne nous
apprend rien. On peut donc s’intéresser plutôt à la moyenne de l’écart
quadratique $(x_i-\bar{x})^2$ qui est une quantité toujours positive et
dont la moyenne  aura toujours une valeur
positive ou nulle (elle sera nulle uniquement si
$x_i-\bar{x}=0,\forall i$)[^8]. On définit donc la *variance*, $v$,
comme étant la moyenne des écarts quadratiques
$$v=\frac{1}{n}\sum_{i=0}^{k-1}n_i(x_i-\bar{x})^2.$$ Si on considère
la racine carrée de la variance, on obtient *l’écart-type*
$$s=\sqrt{v}.$$

---

#### Exercice (Variance, écart-type) {-}

Démontrer les relations suivantes

1. On peut également calculer la variance avec les fréquences
    $$v=\sum_{i=0}^{k-1}f_i(x_i-\bar{x})^2.$$

2. On peut également calculer la variance à l’aide de la formule
    suivante
    $$v=\frac{1}{n}\left(\sum_{i=0}^{k-1}n_ix_i^2\right)-\bar{x}^2= \bar{x^2}-\bar{x}^2$$

---

Pour l’exemple du salaire on obtient pour la variance $$\begin{aligned}
 v&=\frac{1}{61}\left(35\cdot(40000-60656)^2+20\cdot(50000-60656)^2\right.\nonumber\\
 &\quad\quad\left.+5\cdot(60000-60656)^2+1\cdot(1000000-60656)^2\right)\nonumber\\
 &=1.4747\cdot 10^{10},\end{aligned}$$ et l’écart-type
$$s=\sqrt{v}=121440.$$

---

#### Exercice (Variance, écart-type) {-}

Calculer la variance et l’écart type à partir des valeurs du benchmark
de l’application.

---

Encore une fois on constate que la valeur de l’écart-type des salaires
est très dépendante de la valeur extrême de la distribution (1000000
CHF). Si on l’enlève la valeur de l’écart type est de $s=6455$ (un
facteur 20 plus petit que la valeur sur la population complète).

Comme pour la moyenne et la médiane nous pouvons définir des valeurs
plus représentatives. A partir de la fréquence cumulée, $F$, on peut
définir deux grandeurs, $Q_i\in\{x_i\}_{i=0}^{k-1}$ et
$\alpha_i\in[0,1]$ telles que $$F(Q_i)=\alpha_i.$$ En d’autres termes
$Q_i$ est la valeur pour laquelle la fréquence cumulée vaut $\alpha_i$.
$Q_i$ correspond donc au nombre d’individus dont la fréquence cumulée
est de $\alpha_i$. En particulier si $\alpha_i=1/2$, alors
$Q_i=\tilde{x}$ ($Q_i$ est la médiane). Il est commun d’avoir
$Q_i\in[0.25,0.5,0.75]$, on parle alors de quartiles. Avec $Q_1=0.25$ et
$Q_3=0.75$, le nombre d’individus entre $0.25$ et $0.75$ est donné par
$$\frac{Q_3-Q_1}{2}.$$ Cette valeurs est appelée l’intervalle
semi-inter-quartile.


---

#### Exercice (Semi-inter quartile) {-}

Calculer les intervalles semi-inter-quartiles des exemples que nous
avons vus plus tôt dans le cours.

---

Probabilités: Exemple du jeu de dé
----------------------------------

On considère un dé à 6 faces. Le lancer de dé est une *expérience
aléatoire*, car on ne peut dire quel sera le résultat avant d’avoir
effectué l’expérience.

Avant de commencer à étudier les probabilités du lancer de dé, et les
questions qu’on peut se poser, faisons d’abord un peu de vocabulaire qui
sera utile pour la suite.

---

#### Définition {-}

- L’ensemble des résultats possibles du lancer de dé est
    $\Omega=\{1,2,3,4,5,6\}$ et cet ensemble est appelé l’*univers* du
    lancer de dé.
- Chaque résultat possible du lancer de dé ($1$, $2$, etc), noté
    $\omega\in\Omega$, est appelé une *éventualité*.
- Un ensemble de résultats possibles, par exemple tous les résultats
    pairs du lancer de dé $A=\{2, 4, 6\}\in\Omega$, s’appelle un
    *événement*. Un événement composé d’une seule éventualité est appelé
    *événement élémentaire*.
- On dit que l’événement $A$ est *réalisé* si on obtient $2$, $4$, ou
    $6$ en lançant le dé.
- *L’événement certain* est l’univers en entier. On est certain de
    réaliser l’événement.
- *L’événement impossible* est l’ensemble vide, $A=\emptyset$. Il
    correspondrait à l’événement obtenir $7$ ou plus en lançant un dé
    par exemple.
- Si $A$ est un événement, on note $p(A)$ la *probabilité* que $A$
    soit réalisé.

---

Le calcul des *probabilités* de réalisation de certains événement est
reliée à la *fréquence* que nous avons introduit dans la section
précédente. Soit un univers $\Omega$ et $A$, $B$ deux événements tels
que $A\cap B=\emptyset$. On effectue  $N$ expériences, donc $\Omega$
est réalisé $N$ fois. De plus on constate qu’on réalise $A$, $K$ fois et
$B$, $M$ fois. On a donc les fréquences suivantes que $A$, $B$ et
$\Omega$ se réalisent $$\begin{aligned}
 f(A)&=\frac{K}{N},\\
 f(B)&=\frac{M}{N},\\
 f(\Omega)&=\frac{N}{N}=1,\\
 f(A\cup B)&=\frac{M+K}{N}=f(A)+f(B).\end{aligned}$$ Les *probabilités*
de réalisation des événements ci-dessus peuvent être vues comme le
passage à la limite $N\rightarrow\infty$ tel que
$p(A),p(B)\in{\real}$ et $$\begin{aligned}
 p(A)&=\lim_{\substack{N\rightarrow\infty,\\ K/N<\infty}}\frac{K}{N},\\
 p(B)&=\lim_{\substack{N\rightarrow\infty,\\ M/N<\infty}}\frac{M}{N},\\
 p(\Omega)&=1,\\
 p(A\cup B)&=p(A)+p(B).\end{aligned}$$

Si maintenant nous voulons connaître la probabilité de tirer $6$, ou
encore la probabilité de réaliser $A=\{6\}$. Cela est assez intuitif
pour le cas du dé. Nous avons $6$ éléments dans l’univers du lancer de
dé. La probabilité de réaliser $A=\{6\}$ est donc $$p(6)=\frac{1}{6}.$$
Pour le cas du lancer de dé, on dit qu’on a un processus qui est
*équiprobable*. En effet, la probabilité de réaliser chacun des
événements élémentaires est la même. On a en effet la même probabilité
de tirer $1$, $2$, $3$, $4$, $5$, ou $6$.

Si à présent, on se pose la question de la probabilité de réaliser un
tirage pair, $A=\{2,4,6\}$, alors on trouve
$$p(\mbox{tirer un nombre pair})=\frac{1}{2}.$$ De façon générale pour
le lancer de dé, on a que la probabilité de réaliser l’événement $A$
est[^9]
$$p(A)=\frac{\mbox{nombre d'éléments dans }A}{\mbox{nombre d'éléments dans }\Omega}.$$

Si maintenant, on veut savoir quelle est la probabilité de tirer
n’importe quel élément dans l’univers, on a
$$p(\Omega)=\frac{\mbox{nombre d'éléments dans }\Omega}{\mbox{nombre d'éléments dans }\Omega}=1.$$
De même la probabilité de réaliser l’événement impossible est de
$$p(\emptyset)=\frac{\mbox{nombre d'éléments dans }\emptyset}{\mbox{nombre d'éléments dans }\Omega}=0.$$
On voit ici une propriété fondamentale des probabilités qui est que
$0\leq p(A)\leq 1,\ \forall A$.

La probabilité de ne pas tirer un 6 donc de réaliser l’événement
$\bar A=\{1,2,3,4,5\}$ est donnée par $1$ moins la probabilité de
réaliser $A=\{6\}$, il vient $$p(\bar A)=1-p(A)=\frac{5}{6}.$$ De même
la probabilité de tirer un nombre impair, est donnée par $1$ moins la
probabilité de réaliser l’événement pair
$$p(\{1,3,5\})=1-p(\{2,4,6\})=\frac{1}{2}.$$

### Événements disjoints {#sec:disjoints}

Considérons maintenant deux événements, $A=\{1,2\}$ et $B=\{3,4,5\}$.
Comme $A$ et $B$ n’ont pas d’éléments en commun, on dit que c’est deux
événements *disjoints*. Les probabilités de réalisation de ces
événements sont donc $$\begin{aligned}
 p(A)&=\frac{2}{6}=\frac{1}{3},\\
 p(B)&=\frac{3}{6}=\frac{1}{2}.\end{aligned}$$ On va se poser deux
questions à présent

1. On cherche à savoir quelle est la probabilité de réaliser $A$ ou de
    réaliser $B$, donc de tirer un dé dont le résultat sera dans
    l’ensemble $C=A\cup B=\{1,2,3,4,5\}$. Le résultat est
    $$p(C)=\frac{5}{6}.$$ Une coincidence intéressante (qui n’est en
    fait pas une coincidence) est que
    $$p(C)=p(A)+p(B)=\frac{1}{3}+\frac{1}{2}=\frac{5}{6}.$$

2. On cherche à savoir quelle est la probabilité de réaliser $A$ et
    réaliser $B$ en même temps, donc de tirer un dé qui sera dans
    l’ensemble $C=A\cap B=\emptyset$. Ici on a déjà vu que la
    probabilité $p(\emptyset)=0$.

On voit donc que si des événements sont disjoints, alors la probabilité
de réaliser l’un ou l’autre des événements est simplement la somme des
probabilités de réaliser chacun des événements. Inversément la
probabilité de réaliser les deux événements en même temps est nulle.

Nous pouvons facilement décomposer $A$ en deux sous événements
élémentaires, $A=\{1\}\cup \{2\}$. On a donc une autre façon de calculer
$p(A)$
$$p(A)=p(\{1\})+p(\{2\})=\frac{1}{6}+\frac{1}{6}=\frac{2}{6}=\frac{1}{3}.$$
On a que la probabilité de réaliser un événement est la somme des
événements élémentaires qui le composent.

### Événements complémentaires

Considérons de nouveau l’événement $A=\{1,2\}$ et cette fois l’événement
$B=\Omega\backslash \{1,2\}=\{3,4,5,6\}$. L’événement $B$ est appelé
*l’événement complémentaire* de $A$. Il est noté $B=\bar A$. Les
probabilité de réaliser $A$ ou de réaliser $\bar A$ est la même chose
que de réaliser l’événement certain, car $A\cup \bar A=\Omega$. On
vérifie aisément dans ce cas que $$\Omega=\{1,2\}\cup\{3,4,5,6\}$$ et $$p(A\cup \bar A)=p(\Omega)=1.$$ De plus de ce qu’on a vu
précédemment, on a que $$p(A\cup \bar A)=p(A)+p(\bar A).$$ En combinant
ces deux derniers résultats, il vient que $$p(A)+p(\bar A)=1.$$ On en
déduit que $$p(A)=1-p(\bar A)=1-\frac{2}{3}=\frac{1}{3}.$$ Dans ce cas
on peut également calculer à priori $p(B)$
$$p(B)=\frac{\mbox{nombre d'éléments dans }B}{\mbox{nombre d'éléments dans }\Omega}=\frac{4}{6}=\frac{2}{3}.$$
Ce résultat est très important car on calcule facilement $p(\bar A)$ si
on connaît $p(A)$.

### Événements non-disjoints

Considérons de nouveau l’événement $A=\{1,2\}$ et cette fois
$B=\{2,3,4,5\}$. Les probabilités de réaliser les événements respectifs
sont $$\begin{aligned}
 p(A)&=\frac{1}{3},\\
 p(B)&=\frac{2}{3}.\end{aligned}$$ La probabilité de réaliser $A$ et $B$
est maintenant la probabilité de réaliser $C=A\cap B=\{2\}$
$$p(C)=\frac{1}{6}.$$ Si on cherche à présent la probabilité de réaliser
$A$ ou $B$, $D=A\cup B=\{1,2,3,4,5\}$, on voit aisément que
$$p(D)=\frac{5}{6}.$$ Comme $A$ et $B$ ne sont pas disjoints ont
constate $$\frac{5}{6}=p(D)\neq p(A)+p(B)=1.$$ L’inégalité est dûe au
fait que dans le cas où on fait la somme $p(A)+p(B)$ on compte à double
la probabilité de tirer l’éventualité $2$, qui est l’intersection de $A$
et de $B$. Afin de corriger donc le calcul de $p(D)$ à partir de la
somme $p(A)+p(B)$ il suffit d’enlever la probabilité de tirer
l’intersection $C$. On a donc
$$\frac{5}{6}=p(D)= p(A)+p(B)-p(C)=1-\frac{1}{6}=\frac{5}{6}.$$ De façon
complètement générale, on a la relation suivante pour calculer la
probabilité de réaliser l’union de deux événement $A$ et $B$
$$p(A\cup B)=p(A)+p(B)-p(A\cap B).$$ Il en suit immédiatement que si
$A\cap B=\emptyset$, alors
$$p(A\cup B)=p(A)+p(B)-p(A\cap B)=p(A)+p(B)-p(\emptyset)=p(A)+p(B).$$

### Axiomes des probabilités

Tous ces concepts que nous avons vus précédemment peuvent être vus
comme la conséquences des trois axiomes des probabilités suivants

---

#### Définition (Axiomes des probabilités) {-}

Soit $\Omega$ un univers. La probabilité de
réaliser un événement $A\subseteq\Omega$ est une fonction $p(A)$ qui
associe à tout événement de $A$ un nombre réel, qui satisfait les 3
axiomes suivants

1. Une probabilité est TOUJOURS positive $$p(A)\geq 0.$$

2. La probabilité de l’événement certain vaut 1 $$p(\Omega)=1.$$

3. Soit $B\subseteq\Omega$. Si $A\cap B=\emptyset$, alors
    $$p(A\cup B)=p(A)+p(B).$$ La probabilité de réalisation de deux
    événements incompatibles est égale à la somme de réalisation de
    chacun d’entre eux.

---

De ces axiomes découlent tout un tas de théorèmes

---

#### Théorème {-}

Pour $A,B\subseteq\Omega$ et $\Omega$ un univers et $p$ une probabilité.

1. $p(B\cap\bar A)=p(B)-p(B\cap A).$

2. $p(\emptyset)=0.$

3. $p(\bar A)=1-p(A).$

4. $p(A\cup B)=p(A)+p(B)-p(A\cap B).$

5. $p(\bar A\cap \bar B)=1-p(A\cup B).$

6. Si $A$ et $B$ sont disjoints, alors $p(A\cup B)=p(A)+p(B).$

7. Si $A\subseteq B$, alors $p(B\cap \bar A)=p(B)-p(A).$

8. Si $A\subseteq B$, alors $p(A)\leq p(B).$

9. $\forall A$, $0\leq p(A)\leq 1.$

---

### Probabilités conditionnelles

Imaginons à présent que nous ayons une information supplémentaire
lorsque nous lançons notre dé. Supposons par exemple que nous sachions
lorsque nous lançons le dé que le résultat est pair. A partir de là la
probabilité de tirer un $6$ est de
$$p(6\mbox{ sachant que le résultat du lancer est un nombre pair})=1/3,$$
alors que sans l’information sur la parité nous aurions eu $p(6)=1/6$.

Lorsque nous rajoutons comme condition la réalisation préalable d’un
événement $B$ à la réalisation d’un événement $A$, nous parlons de
probabilité conditionnelle, notée $P(A|B)$ (probabilité conditionnelle
de $A$ sachant que $B$ s’est produit).

Essayons à présent de voir comment nous pouvons calculer de façon
générale les probabilités conditionnelles avec notre exemple ci-dessus.
Nous avons donc que nous cherchons à calculer $p(A|B)=p(6|{2,4,6})$.
Nous avons dans ce cas que $p(A)=1/6$, $p(B)=1/2$ et
$p(A\cap B)=p(6)=1/6$. Par ailleurs, nous pouvons remarquer que
$$p(A|B)=\frac{1}{3}=\frac{p(A\cap B)}{p(B)}=\frac{\frac{1}{6}}{\frac{1}{2}}.$$
Nous pouvons vérifier cette relation sur un exemple un peu plus
compliqué. Soit $A={1,2,4}$ et $B={2,4,6}$. La probabilité
conditionnelle $p(A|B)$ revient au calcul de la probabilité de
$p(A\cap B|B)=p({2,4}|{2,4,6})=2/3$. Avec notre formule, nous avons
$p(A\cap B)=1/3$ et $p(B)=1/2$. Il vient donc
$$p(A|B)=\frac{p(A\cap B)}{p(B)}=\frac{2}{3}.$$ Cette formule peut en
fait être vue comme la définition de la probabilité conditionnelle. Si
$p(B)\neq0$ alors on appelle probabilité conditionnelle le nombre
$p(A|B)$, tel que $$p(A|B)=\frac{p(A\cap B)}{p(B)}.$$

---

#### Exercice (Probabilités conditionnelles) {-}

Sur une population de 1000 hommes qui naissent, 922 atteignent l’âge de
50 ans et 665 l’âge de 70 ans.

1. Quelle est la probabilité qu’un homme qui vient de naître soit
    encore en vie à 50 ans?

2. Quelle est la probabilité qu’un homme qui vient de naître soit
    encore en vie à 70 ans?

3. Quelle est la probabilité qu’un homme de 50 ans soit encore en vie à
    70?

---

### Événements indépendants

Prenons maintenant le cas “pathologique” où nous cherchons la
probabilité conditionnelle $p(A|B)$, mais où la réalisation de $B$ n’a
aucune influence sur la réalisation de $A$. On a donc $$p(A|B)=p(A).$$
Il vient $$p(A|B)=\frac{p(A\cap B)}{p(B)}=p(A).$$ On en déduit que
$$p(A\cap B)=p(A)\cdot p(B).$${#eq:indep} On calcule aussi 
$p(B|A)$
$$p(B|A)=\frac{p(A\cap B)}{p(A)}=\frac{p(A)\cdot p(B)}{p(A)}=p(B).$$ 
Donc si $A$ ne dépend pas de $B$, alors la réciproque est vraie
aussi. Les événements qui satisfont la propriété de l’équation
@eq:indep sont appelés indépendants. Dans le cas contraire ils
sont appelé dépendants.

Afin d’illustrer l’indépendance, prenons à nouveau le jet de dé.
Supposons que nous effectuions deux tirages de suite et que l’événement
$A$ soit “tirer un 6 au premier tirage” et que l’événement $B$ soit
“tirer un $2$ au deuxième tirage”. On a que
$$p(A)=\frac{1}{6},\quad p(B)=\frac{1}{6},\quad p(A\cap B)=\frac{1}{36}.$$
On a donc bien $p(A\cap B)=p(A)\cdot p(B)$ et les événements sont
indépendants. Cela semble bien naturel étant donné que le premier tirage
du dé ne va en rien influencer le résultat du deuxième tirage. Tout
comme un tirage de l’euromillions d’une semaine ne va pas influencer le
résultat de celui de la semaine suivante.

---

#### Exercice (Événements indépendants)  {-}

On jette une pièce de monnaie deux fois de
suite. Les résultats possible pour chaque jet sont: $P$, ou $F$.

1. Écrivez l’univers des événements.

2. Calculez les probabilités des événements $A$ “face au premier jet”,
    $B$ “pile au second jet”.

3. Calculez la probabilité $p(A\cap B)$.

4. Est-ce que les jets sont indépendants?

---

### Tirages multiples

Jusqu’ici on a lancé le dé une fois et calculé la probabilité liée à ce
lancer unique. A présent, on va tirer le dé plusieurs fois et calculer
les probabilités d’obtenir des séquences de réalisations. Pour notre
exemple on va prendre un cas où on tire le dé deux fois successivement.
Ce type de tirage est appelé *tirage successif avec remise*, car les
deux tirages sont successifs et indépendants entre eux (on va tirer deux
fois le même dé). L’univers de cette expérience est la combinaison de
tous les résultats obtenus avec chacun des dés
$$\Omega=\{11,12,13,14,15,16,21,22,23,24,25,26,...,61,62,63,64,65,66\}.$$
Il y a $6\times 6=6^2=36$ résultats possibles à ce tirage. Il faut noter
ici que l’ordre dans lequel le tirage a lieu est important; le tirage
$26$ est différent du tirage $62$. On verra par la suite des exemples où
cela n’est pas le cas.

On cherche à savoir quelle est la probabilité d’obtenir l’événement
$A=\{26\}$.

Comme précédemment la probabilité de réaliser l’événement $A$ est le
nombre d’éléments dans $A$ divisé par le nombre d’éléments dans
$\Omega$. La probabilité est donc immédiatement obtenue
$$p(A)=\frac{1}{36}.$$ Une autre façon de visualiser ce genre de
réalisation est de l’écrire sous forme d’arbre (voir la figure
@fig:arbre).

![Représentation du tirage $26$ sous forme
d’arbre.](figs/arbre.svg){#fig:arbre width="\textwidth"}

Comme pour le cas à un tirage, tout tirage successif de dés est
équiprobable et la probabilité de chaque tirage est de $1/36$.

Une autre façon de calculer la probabilité d’obtenir $A=\{26\}$ est de
constater que la probabilité d’obtenir ce tirage successif est la
probabilité de tirer $2$, puis la probabilité de tirer $6$. La
probabilité de cet enchaînement est obtenu en multipliant les événements
élémentaires
$$p(\{26\})=p(\{2\})\cdot p(\{6\})=\frac{1}{6}\cdot\frac{1}{6}.$$

![Représentation du tirage $26$ sous forme d’arbre avec les probabilités
associées.](figs/arbre2.svg){#fig:arbre2 width="\textwidth"}

Afin de calculer la probabilité du tirage $26$ il suffit de suivre le
chemin menant de la racine à la feuille correspondante et de multiplier
les probabilités inscrites sur chacune des branches.

Si à présent, nous voulons savoir quelle est la probabilité de tirer un
$2$ ou un $4$ avec le premier dé et un nombre pair avec le second, on a
trois façons de calculer le résultat. La façon compliquée, où on compte
toutes les possibilités. L’événement précédent s’écrit
$$A=\{22,24,26,42,44,46\}.$$ On a donc que $p(A)$ est donné par
$$p(A)=\frac{\mbox{nombre d'éléments dans }A}{\mbox{nombre d'éléments dans }\Omega}=\frac{6}{36}=\frac{1}{6}.$$
L’autre façon (plus simple) est d’utiliser la propriété du produit des
probabilité. Nous savons que la probabilité de tirer un $2$ ou un $4$
avec le premier dé est de $1/3$, puis la probabilité de tirer un nombre
pair avec le deuxième est de $1/2$. On a donc finalement que
$$p(A)=\frac{1}{3}\cdot\frac{1}{2}=\frac{1}{6}.$$ Finalement, on peut
aussi utiliser la représentation sous forme d’arbre où on somme
simplement les probabilités de chacun des éléments de $A$ (voir figure
@fig:arbre3).

![Représentation de l’événement $A=\{22,24,26,42,44,46\}$ sous forme
d’arbre avec les probabilités associées. Toutes les probabilités et
tirages possibles associés aux branches ne sont pas affichées pour
simplifier
l’affichage.](figs/arbre3.svg){#fig:arbre3 width="\textwidth"}

Comme vu dans la section @sec:disjoints, il suffit de prendre la
somme des probabilités des événements élémentaires $$\begin{aligned}
 p(A)&=p(\{22\})+p(\{24\})+p(\{26\})+p(\{42\})+p(\{44\})+p(\{46\})\nonumber\\
     &=\frac{1}{36}+\frac{1}{36}+\frac{1}{36}+\frac{1}{36}+\frac{1}{36}+\frac{1}{36}\nonumber\\
     &=\frac{6}{36}=\frac{1}{6}.\end{aligned}$$

Si à présent l’ordre dans lequel les dés sont tirés n’a plus
d’importance le calcul de probabilités change un peu. On désire savoir
quelle est la probabilité d’obtenir $26$ dans un ordre arbitraire. On
peut donc obtenir cette combinaison en tirant $26$ ou en tirant $62$. On
a donc $A=\{26,62\}$. La probabilité de réaliser $A$ est donc
$$p(A)=\frac{2}{36}=\frac{1}{18}.$$ On peut calculer cette probabilité
de nouveau avec l’arbre ou en comptant. Une façon de nouveau plus simple
dans bien des cas est d’utiliser les produits de probabilités. La
probabilité de tirer $26$ ou $62$ est la probabilité de tirer d’abord
$2$ ou $6$, puis de tirer le nombre restant ($2$ si on a d’abord tiré
$6$ ou $6$ si on a d’abord tiré $2$). La probabilité de tirer $2$ ou $6$
est de $1/3$, puis la probabilité de tirer le nombre restant est de
$1/6$. On a donc que $$p(A)=\frac{1}{3}\cdot \frac{1}{6}=\frac{1}{18}.$$

---

#### Exercice {-}

1. Calculer la probabilité d’obtenir $2$ comme la somme des deux
    nombres tirés par deux dés.

2. Calculer la probabilité d’obtenir $3,4,5,6,7,8,9,10,11,12$ comme la
    somme des deux nombres tirés par deux dés.

3. Calculer la probabilité d’obtenir $7$ comme la somme des deux
    nombres tirés par deux dés.

4. Calculer la probabilité d’obtenir $6$ soit avec 1 soit avec 2 dés.

5. Déterminer le nombre de combinaisons possibles avec 3, 4, 5 dés.
    Pouvez vous généraliser à $n$ dés?

6. Soit un tirage aléatoire offrant 2 possibilités (pile ou face par
    exemple). Quel est le nombre de combinaisons possibles si on tire
    $n$ fois? Pouvez-vous généraliser pour un tirage aléatoire offrant
    $m$ possibilités qu’on tire $n$ fois?

---

### La distribution multinomiale

Plus nous allons rajouter des tirages successifs plus il va être
compliqué de calculer les probabilités de tirer une certaine combinaison
de nombres. Il existe néanmoins une formule qui généralise les tirages
successifs avec remise. Prenons le cas où nous avons un dé qui ne donne
pas chaque nombre de façon équiprobable, mais avec probabilité
$\{p_i\}_{i=1}^6$. Nous souhaitons savoir quelle est la probabilité de
tirer deux fois le 1 et une fois le 2 lors de trois tirages successifs.

Dans ce tirage l’ordre dans lequel sont obtenus ces tirages ne sont pas
importants. Il y a donc les tirages possibles qui sont admissibles
$$[112]=\{112, 121, 211\}.$$ On a donc que la probabilité associée est
de $$p([112])=p(112)+p(121)+p(211).$$ Ces trois probabilités sont
données par $$\begin{aligned}
 p(112)&=p_1\cdot p_1\cdot p_2=p_1^2\cdot p_2,\\
 p(121)&=p_1\cdot p_2\cdot p_1=p_1^2\cdot p_2,\\
 p(211)&=p_2\cdot p_1\cdot p_1=p_1^2\cdot p_2.\end{aligned}$$ Les
tirages étant indépendants  on a que la probabilité de
tirer $1$ ou $2$ est indépendante du moment où ils sont tirés et donc
ces trois probabilités sont égales.

Finalement la probabilité de tirer deux 1 et un 2 est de
$$p([112])=p(112)+p(121)+p(211)=3\cdot p_1^2\cdot p_2.$$ A présent
nous considérons la probabilité de tirer $[1123]$ en 4 tirages. Les
tirages possibles sont
$$[1123]=\{1123, 1132, 1213, 1231, 1312, 1321, 2113, 2131, 2311, 3112, 3121, 3211\}.$$
Il y a donc 12 tirages possibles pour cette combinaison. De plus les
tirages étant indépendants on a que toutes ces combinaisons sont
équiprobables avec probabilité $$p(1123)=p_1^2p_2p_3.$$ Finalement on a
$$p([1123])=12 p_1^2p_2p_3.$$ Si nous définissons $n_i$ le nombre de
fois où on obtient le résultat $i$ et qu’on cherche la probabilité de
réaliser le tirage $[n_1,n_2,...,n_k]$, on constate que la probabilité
de réaliser le tirage est proportionnelle à
$p_1^{n_1}p_2^{n_2}\cdots p_6^{n_6}$. Il nous reste à déterminer le
facteur multiplicatif venant devant. Pour le cas du tirage $1,1,2$, nous
avons $[n_1n_2]$ avec $n_1=2$ et $n_2=1$ et le facteur devant le produit
des probabilités est donné par $3$. Pour le tirage $1,1,2,3$ il est de
$12$ et nous avons $n_1=2$, $n_2=1$, $n_3=1$. Nous pouvons écrire
$$3=\frac{3!}{1!2!}\mbox{ et } 12=\frac{4!}{1!1!2!}.$$ En fait on peut
constater que $$\frac{n!}{n_1!n_2!\cdots n_6!},$$ avec
$n=\sum_{i=1}^6 n_i$. On a donc que
$$p([n_1,n_2,...,n_6])=\frac{n!}{n_1!\cdots n_6!}p_1^{n_1}\cdots p_6^{n_6}.$$
De façon complètement générale ce genre de probabilité se calcule grâce
à la *distribution multinomiale*
$$p([n_1,...,n_k])=\frac{n!}{n_1!\cdots n_k!}p_1^{n_1}\cdots p_k^{n_k}.$$

---

#### Exercice {-}

On lance un dé parfait 10 fois. Quelle est la probabilité d’obtenir:

1. 10 fois 6?

2. 4 fois 3, 3 fois 2 et 3 fois 1?

3. 2 fois 1, 2 fois 2, 2 fois 3, 1 fois 4, 1 fois 5, et 1 fois 6?

---

Exemple du lotto
----------------

Dans un lotto on a dans une urne (souvent une machine spécialement conçue contenant de petites bales numérotées)  
un nombre de jetons numérotés, disons
pour l’exemple entre 1 et 6, qui sont tirés successivement. Une fois un
jeton tiré, il ne sera pas remis dans le sac. On appelle ce genre de
tirage *sans remise*. Contrairement au cas des dés vus dans la section
précédente qui était ‘*avec remise*. On tire un nombre fixé de jetons,
disons 3. On souhaite déterminer la probabilité d’obtenir une suite
donnée de 2 numéros, disons $25$. Disons aussi que pour cet exemple l’ordre du
tirage a de l’importance (ce qui n’est pas le cas du lotto).

Afin de calculer cette probabilité le fait qu’on effectue un tirage avec
remise est primordial. En effet considérons le cas initial illustré dans
la @fig:loto.

![Les six numéros présents initialement dans le
sac.](figs/loto.svg){#fig:loto height="1.8truecm"}

Pendant le premier tirage, nous tirons le numéro 2 (voir figure
@fig:loto2). Notons que le tirage du 2 a une probabilité
$\frac{1}{6}$.

![Le numéro 2 est tiré lors du premier
tirage.](figs/loto2.svg){#fig:loto2 height="1.8truecm"}

Il est donc enlevé du sac et il nous reste uniquement 5 chiffres parmi
lesquels choisir (les chiffres $1$, $3$, $4$, $5$, et $6$, comme dans la
@fig:loto3).

![Il ne reste que 5 chiffres dans le
sac.](figs/loto3.svg){#fig:loto3 height="1.8truecm"}

Comme il ne nous reste que 5 chiffres, la probabilité de tirer un des
nombres restant, disons le $5$, est de $\frac{1}{5}$ (voir la figure
@fig:loto4).

![Il ne reste que 5 chiffres dans le sac et nous tirons le
5.](figs/loto4.svg){#fig:loto4 height="1.8truecm"}

Le 5 sera lui aussi retiré et il ne restera que 4 numéros dans le sac et
ainsi de suite.

On voit donc que la probabilité de tirer la suite ordonnée $25$ est de
$$p(\{25\})=p(\{2\})\cdot p(\{5\})=\frac{1}{6}\cdot\frac{1}{5}=\frac{1}{30}.$$
A présent, si nous considérons que l’ordre n’a pas d’importance, on a
comme dans la section précédente que l’événement qui nous intéresse est
$A=\{25,52\}$. On peut donc décomposer ce cas en 2 et dire qu’on a dans
un premier temps la probabilité de tirer $2$ ou $5$ parmi $6$ nombres,
puis on a la probabilité de tirer le $5$ ou le $2$ (respectivement si on
a tiré $2$ ou $5$) parmi 5. Les deux probabilités sont donc données
respectivement par $p(\{2,5\})=\frac{2}{6}$ puis par
$p(\{5,2\}\backslash \{2\mbox{ ou }5)=\frac{1}{5}$ pour trouver la probabilité $\frac{1}{15}$.

---

#### Exercice {-}

1. Le jeu Euromillions consiste en un tirage de 5 numéros parmi 50
    possible, puis par le tirage de 2 “étoiles” parmi 11 possibles.
    Déterminez la probabilité de trouver la bonne combinaison à un
    tirage.

2. Le jeu du swiss lotto, consiste au tirage de 6 numéros parmi 42
    possibles, puis au tirage d’un numéros parmi 6. Calculez la
    probabilité de gagner au swiss lotto.

---

Quelques exercices
------------------

Afin de continuer avec ces concepts de tirages aléatoires avec ou sans
remise de suites ordonnées ou non, nous allons faire quelques exercices.
Il peut se révéler utile de dessiner un arbre pour ces exercices.

1. Dans une urne se trouvent 2 boules blanches et 3 boules noires. On
    tire successivement deux boules sans remise. Calculer et comparer
    les probabilités des deux événements suivants

    - Tirer deux boules de même couleur.

    - Tirer deux boules de couleurs différentes.

2. Une bille, lâchée en $O$ tombe dans l’une des trois boîtes $A$, $B$,
    ou $C$. A chaque bifurcation, la bille tombe à gauche avec la
    probabilité de 0.25 et à droite avec la probabilité de 0.75 (voir
    @fig:bille)

    ![Une bille lâchée en $O$ tombe dans la boîte $A$, $B$, ou
    $C$.](figs/bille.svg){#fig:bille height="2.8truecm"}

    - Calculer les probabilités $p(A)$, $p(B)$, $p(C)$ pour qu’une
        bille lâchée de O tombe respectivement dans la boîte $A$, $B$ ou
        $C$.

    - On lâche deux billes en $O$. Calculer la probabilité pour que
        les deux billes tombent dans la même boîte.

    - On lâche trois billes en $O$. Calculer la probabilité d’avoir
        une bille dans chaque boîte.

    - On lâche dix billes en $O$. Calculer la probabilité d’avoir au
        moins trois billes dans la boîte B.

3. A la naissance, la probabilité qu’un enfant soit un garçon est de
    $p(G)=0.514$.

    - Calculer et la probabilité qu’un enfant soit une fille.

    - On considère la naissance de deux enfants. Calculer et la
        probabilité que les deux enfants soient de même sexe.

    - On considère la naissance de deux enfants. Calculer et la
        probabilité que les deux enfants soient de sexes différents.

Variables aléatoires
--------------------

Lors d’une expérience aléatoire, il est assez commun de relier chaque
événement de l’univers, $A\in\Omega$, à un nombre réel,
$X(A)\in{\real}$. Cette relation est définie par une fonction qui
porte le nom de variable aléatoire et peut s’écrire mathématiquement
sous la forme $$X:\Omega\rightarrow {\real}.$$ Afin de mieux
comprendre ce concept voyons quelques exemples

1. Lors d’un jet de dé unique l’univers est défini par
    $\Omega=\{1,2,3,4,5,6\}$. On peut de façon assez naturelle définir
    notre variable aléatoire comme $$X:i\rightarrow i.$$

2. Si nous lançons une pièce de monnaie les deux issues possibles sont
    pile $p$, ou face $f$ ($\Omega={p,f}$). Nous pouvons définir la
    variable aléatoire $X$ comme $$X:\left\{\begin{array}{l}
                    p\rightarrow 0\\
                    f\rightarrow 1
                   \end{array}\right.$$

3. Si nous lançons une pièce de monnaie à deux reprises, les issues
    possibles sont $(p,p)$, $(p,f)$, $(f,p)$, $(f,f)$. Nous pouvons
    définir la variable aléatoire $X$ comme $$X:\left\{\begin{array}{l}
                    (p,p)\rightarrow 0\\
                    (p,f)\rightarrow 1\\
                    (f,p)\rightarrow 1\\
                    (f,f)\rightarrow 2
                   \end{array}\right.$$

Comme nous nous sommes posés la question de connaître la probabilité
d’obtenir un certain résultat lors d’une expérience aléatoire, il en va
de même avec la probabilité que la variable aléatoire $X$ prenne une
valeur donnée, $\alpha\in{\real}$ ou prenne une valeur incluse dans
un intervalle $I\subseteq{\real}$.

Pour illustrer ce qui se passe, intéressons-nous au dernier exemple
ci-dessus avec le double pile ou face. On se pose les questions
suivantes

1. Quelle est la probabilité que $X$ prenne la valeur $1$?

2. Quelle est la probabilité que $X$ prenne une valeur incluse dans
    $I=[0.6,3]$?

3. Quelle est la probabilité que $X$ prenne une valeur inférieure à
    $2$?

Prenons ces trois questions une par une

1. Les deux façons d’obtenir $X=1$ est d’avoir les tirages $(p,f)$ ou
    $(f,p)$, soit $A=\{(p,f), (f,p)\}$. Les probabilités de chacun des
    événements de l’univers étant équiprobables on a
    $$p(X=1)=p(A)=1/2.$$

2. Le seul événement donnant un $X$ qui n’est pas dans l’intervalle
    $J=[0.6,3]$ est $B=(p,p)$ ($X(B)=0$). On a donc que
    $$p(0.6\leq X\leq 3)=p(\bar B)=1-p(B)=\frac{3}{4}.$$

3. De façon similaire les trois événements donnant $X<2$ sont dans
    $C=\{(p,p), (p,f), (f,p)\}$. On a donc $$p(X<2)=p(C)=\frac{3}{4}.$$

On constate au travers de ces trois exemples que la probabilité que la
variable aléatoire $X$ prenne une valeur particulière $\alpha$ ou soit
dans un intervalle $I$ est reliée à la probabilité d’obtenir un
événement $D$ qui serait la préimage de $\alpha$ ou d’un intervalle $I$.
On peut noter dans le cas général qu’on a $D=X^{-1}(I)$.

---

#### Définition (Variable aléatoire) {-}

On dit que la fonction $X:\Omega\rightarrow{\real}$ est une
*variable aléatoire* si la préimage de $X$ sur tout intervalle,
$I\subseteq{\real}$, est un événement $A\in \Omega$. La probabilité
que $X$ prenne une valeur dans l’intervalle $I$ est égale à la
probabilité de réaliser l’événement $A$ $$p(X\in I)=p(A).$$

---

---

#### Définition (Fonction de répartition) {-}

On dit que la fonction $F:{\real}\rightarrow{\real}$ est une
*fonction de répartition* si $F(x)=p(X\leq x)$ pour tout
$x\in{\real}$.

---

Nous distinguons deux sortes de variables aléatoires: les
variables aléatoires discrètes et continues. Nous les discuterons
brièvement dans les deux sous-sections suivantes.

Nombres aléatoires
------------------

Les nombres aléatoires, bien que pas directement reliés aux
probabilités, sont utilisés dans un certain nombre de domaines qui vont
de la cryptographie aux simulations physiques. Nous allons voir une
introduction simplifiée à la génération de nombres aléatoires sur un
ordinateur et les différentes problématiques reliées à leur génération.

Une très bonne référence concernant les nombre aléatoires est le site
`http://www.random.org`.

### Générateurs algorithmiques: une introduction (très) générale

Le but des générateurs de nombres aléatoires est de produire une suite
de nombres entiers, ($n\in{\mathbb{N}}$) $$\{X_0,X_1,...,X_n\},$$ avec
$X_i\in A$, où $A=[0,m]$, avec $m\in {\mathbb{N}}$ (dans le cas de la
fonction `rand()` de $C$, $M$ est donné par la constante prédéfinie
`RAND_MAX` qui and certains cas est $2^{31}-1$). La probabilité de tirer
chacun des nombres dans l’intervalle $A$ est égale. On dit que la
distribution des nombres est uniforme. De plus, les nombres tirés ne
doivent pas dépendre de l’histoire des nombres tirés précédemment et on dit que les nombres sont indépendants.

Si on veut maintenant plutôt tirer des nombres réels uniformément
distribués entre $[0,1]$, il suffit de diviser les nombres $X_i$ par $m$
après chaque tirage. De façon similaire, si nous voulons tirer des
nombres dans l’intervalle $[\alpha,\beta]$, on utilise la formule de
remise à l’échelle suivante $$N_i=\alpha+(\beta-\alpha)X_i/m.$$ Il faut
remarquer que pour que cette formule puisse est utilisée il est
nécessaire que $(\beta-\alpha)<M$.

Les transformations que je donne ici ne sont pas toujours celles
implémentées. En effet, il existe des transformations beaucoup plus
efficaces d’un point de vue computationnel pour changer l’intervalle des
nombres aléatoires.

Sans entrer dans les détails, la génération de nombres aléatoires
n’ayant pas une distribution uniforme s’obtient en effectuant une
transformation un peu plus complexe que celle ci-dessus en partant
toujours de la suite de nombres aléatoires entiers.

Les nombres aléatoires produits de façon algorithmique (donc avec un
ordinateur) ne peuvent pas être vraiment aléatoires, car ils sont obtenus
avec une machine déterministe (les opérations faites à l’aide d’un
ordinateur sont par définition reproductibles avec une chance d’erreur
quasiment nulle). On parle donc de nombre pseudo-aléatoires.

Néanmoins, bien que ces chiffres ne soient pas vraiment aléatoires, ils
peuvent posséder des propriétés qui les rendent satisfaisants pour la
plupart des applications. Cette suite de nombres doit avoir des
propriétés particulières quand $m\rightarrow\infty$. Sans entrer pour le
moment trop dans les détails, on veut par exemple que la moyenne des
nombres tirés soit $m/2$, que la corrélation entre des sous-suites de
nombres soit nulle, ou encore qu’il n’existe pas de séquence qui se
répète (ou au moins que la période de répétition soit très très longue).
Néanmoins, il est assez compliqué de définir des tests très robustes
pour évaluer la qualité des nombres aléatoires algorithmiques.

### Les générateurs congruenciels linéaires {#sec:congr}

Pendant très longtemps, les générateurs de nombres aléatoires
algorithmiques ont été des générateurs congruenciels linéaires, dont la
génération est donné par la formule suivante. Soit $X_i$ un nombre
aléatoire, alors le prochain nombre de la série est donné par
$$X_{i+1}=(aX_i+c)\mod m,$$ où $a$, $c$ et $m$ sont des paramètres de
notre générateur. On constate que la seule partie éventuellement
aléatoire de n’importe quelle séquence est la valeur initiale de notre
séquence $X_0$ (aussi appelée *graine*). Tous les autres nombres obtenus
sont déterministes. Pour chaque valeur de graine, on aura toujours la
même séquence de nombre tirés.

Il est très important de noter que la qualité des nombres aléatoires
obtenus sont extrêmement dépendants des valeurs de $a$, $c$ et $m$
choisies (et des relations entre elles). Si par exemple, on choisit
$a=1$, $c=1$, $m=10$ et $X_0=0$, on va avoir comme suite de nombre
aléatoire $$\{0,1,2,3,4,5,6,7,8,9,0,1,2,3,...\},$$ ce qui n’est pas très
aléatoire vous en conviendrez... Il est donc très important de tenter
d’optimiser les valeurs $a$, $c$ et $m$ pour avoir des séquences aussi
“aléatoires” que possible.

Une première chose à remarquer c’est que $m$ sera la valeur maximale de
la période de notre générateur de nombre aléatoire (la période est le
nombre de tirages qu’il faudra effectuer pour que la série se répète
exactement).

Quelques paramètres utilisés dans des générateurs connus sont par
exemple

- la fonction `rand()` du langage $C$
    $$a=1103515245,\quad c=12345,\quad m=2^{32}.$$

- la fonction `drand()` du langage $C$
    $$a=25214903917,\quad c=11,\quad m=2^{48}.$$

- le générateur `RANDU` des ordinateurs IBM des années 1960
    $$a=65539,\quad c=0,\quad m=2^{32}.$$

Ce genre de générateur de nombres aléatoires est très efficace d’un
point de vue computationnel mais la qualité des nombres aléatoires est en général 
insuffisante. Plusieurs améliorations ont été proposées. Par
exemple, pour chaque étape, on peut générer $k$ nombres aléatoires avec
un générateur congruentiel linéaire et combiner les nombres.

La méthode probablement la plus populaire consiste à utiliser des
récurrences matricielles sur la représentation binaire des nombres. Soit
$\tilde X_i$ la représentation sur $k$ bits de $X_i$, alors
$\tilde X_{i+1}$ est donné par $$\tilde X_{i+1}=A \tilde X_i \mod 2,$$
où $A$ est une matrice $k\times k$. Ce genre de générateur a l’énorme
avantage d’être extrêmement efficace. Ils sont à la base de l’algorithme
Mersenne Twister. Ces générateurs ont généralement une période
extrêmement longue (qui a la particularité d’être un nombre premier de
type Mersenne dont la forme est $m=2^l-1$, avec $l\in{\mathbb{N}}$).

Bien que ne soyant pas parfaits ces générateurs ont aussi le grand avantage
d’être très rapides et peu gourmands en ressources de calcul. La
facilité de description et d’utilisation de tels générateurs, permet des
tests très poussés quant à leur qualités et leurs limites par la
communauté scientifique. Finalement, les besoins de débogage de codes,
la reproductibilité d’une série de nombres aléatoires peut être d’un
grand secours.

### Les générateurs physiques

Une autre façon de générer des nombres aléatoires, serait d’utiliser des
phénomènes physiques qui contiennent de façon inhérente des processus
aléatoires. On peut imaginer lancer un dé “à la main”, mesurer les
émissions radioactives d’atomes (mesurer leur spin), etc... Ou encore
effectuer des lancer de jeux aussi peu biaisés que possibles (roulette,
dé, etc).

Néanmoins, cette façon de faire a un certain nombre de désavantages. Le
premier est que l’acquisition des données “en temps réel” de ces
processus est en général plusieurs ordres de grandeurs trop lente par
rapport aux besoins pratiques. Par rapport à un générateur algorithmique
très peu coûteux, un dispositif “physique” peut être très coûteux en
espèces sonnantes et trébuchantes.

Il a néanmoins été envisagé de stocker de très grandes quantités de
nombres aléatoires sur un support quelconque et de les fournir à
l’utilisateur quand cela s’avère nécessaire. Le problème principal qui a
été révélé par cette façon de faire est que le processus de mesure des
différents processus est loin d’être parfait et engendre des biais
importants dans la qualité des nombres obtenus ce qui les rend souvent
en pratique moins bons que les nombres obtenus avec des générateurs de
nombres pseudo-aléatoires...

### Comment décider si une suite de nombres pseudo-aléatoires peut être considérée comme aléatoire

Cette question est extrêmement compliquée. Pour simplifier considérons
le tirage de nombres entiers $X_i\in \{0,1\}$. Les tirages aléatoires
sont uniformément distribués, on a donc que $p(0)=p(1)=1/2$. Supposons
qu’on obtient une suite de 10 nombres avec deux générateurs différents
$$\begin{aligned}
 X&=\{0,0,1,1,1,0,1,0,1,0\},\\
 Y&=\{0,0,0,0,0,0,0,0,0,0\}.\end{aligned}$$ On voit que la suite $Y$
semble beaucoup moins aléatoire que la suite $X$. En effet, la
probabilité de tirer 10 fois 0 en 10 tirages est de
$p(Y)=1/2^{10}=1/1024$, alors que la probabilité d’avoir autant de 0 que
de 1 est de $1/2$. De façon générale on aimerait que la répartition
soit $35\%$-$65\%$ avec une probabilité de $90\%$.

Néanmoins, ce critère n’est pas suffisant. En effet la suite
$$Z=\{0,1,0,1,0,1,0,1,0,1\},$$ satisfait bien le critère ci-dessus. En
revanche la probabilité de n’avoir pas deux tirages $0$ ou $1$ de suite
est très faible (moins de $5\%$).

De ces constatations on peut dire qu’un générateur de nombres
pseudo-aléatoires est de bonne qualité si les tirages qui sont effectués
vérifient les propriétés du tirage avec une forte probabilité. On
constate que cette définition est vague. En particulier la définition de
“forte” est pas très précise. Il faut cependant noter que souvent nous
sommes intéressés à des suites qui ont une longueur $n$. Donc pour
$n\rightarrow\infty$ on va vouloir que les probabilités vont toutes
tendre vers $1$.

Néanmoins, il est certain qu’aucun générateur ne peut être parfait. En
effet, les nombres étant toujours représentés avec une précision finie,
il est impossible d’être capable de représenter exactement toutes les
propriétés d’une série de nombres vraiment aléatoires avec un générateur
pseudo-aléatoire. On va donc plutôt considérer une autre définition pour
la qualité d’un générateur algorithmique.

Considérons une simulation nécessitant la génération de nombres
aléatoires. Un “bon” générateur de nombres pseudo-aléatoire produit une
série de nombres qui peut être utilisée en lieu et place de vrai nombres
aléatoires sans que la simulation n’en soit affectée. Par exemple, le
calcul du nombre $\pi$ vu dans les exercices doit être trouvé avec la
précision désirée avec le générateur de nombre pseudo-aléatoires pour
que celui-ci soit considéré comme bon.

### Quelques règles générales

La règle précédente bien que satisfaisante, n’est pas forcément simple à
tester. En effet, il ne permet pas de prévoir la qualité d’un générateur
a priori. Il nous faut donc quelques qualités minimales pour les
générateurs de nombres aléatoires.

#### La périodicité

Tout générateur de nombres pseudo-aléatoires va à un moment ou un autre
devenir périodique (la séquence de nombres générés vont se répéter à
l’infini). Notons la période du générateur aléatoire $T$. Il est évident
que dès qu’on atteint un nombre de tirages équivalent à la période
(${\mathrm{card}}(X)\sim T$), on va avoir des nombres pseudo-aléatoires
qui ne sont plus du tout satisfaisants. En fait on peut montrer que des
problèmes apparaissent dès que le nombre de tirages atteint un nombre
équivalent à $T^{1/3}$. Une condition primordiale pour avoir un “bon”
générateur de nombres pseudo-aléatoire est donc une période élevée. Pour
des générateurs aléatoires modernes, un période $T<2^{100}$ n’est pas
considérée comme satisfaisante pour la plupart des applications.

Évidemment il est impossible de tester la périodicité de tels
générateurs de façon expérimentale ($2^{100}\sim 10^{30}$). Cela ne peut
se faire que par des études analytiques approfondies. Comme expliqué
dans la  @sec:congr la période maximale d’un générateur
congruentiel linéaire est $m$. Dans les 3 exemples donnés la période est
respectivement de $2^{32}$, $2^{48}$, ou $2^{32}$. Ils ne devraient donc
plus être utilisés dans des applications modernes. A titre de
comparaison le générateur Mersenne Twister possède une période de
$2^{19937}-1$.

Il est évident que la période à elle seule ne suffit pas à déterminer si
un générateur de nombres pseudo-aléatoires est bon. En particulier on
peut prendre un générateur congruentiel, où $$X_{i+1}=(X_i+1)\mod m,$$
avec $m$ aussi grand qu’on veut (disons $m=2^{2000}$ par exemple) mais
la séquence de nombres générés ne sera absolument pas aléatoire, étant
donné qu’on aura
$$X=\{0, 1, 2, 3, 4, 5, 6, ..., 2^{2000}-1, 0, 1, 2, ...\},$$ si
$X_0=0$. Cela pourrait ne pas être problématique en soi, si la séquence
avec une graine $X_0=1$ n’était pas si similaire
$$X=\{1, 2, 3, 4, 5, 6, ..., 2^{2000}-1, 0, 1, 2, ...\}.$$ Il est donc
nécessaire d’avoir d’autres critères que la seule période. C’est le
sujet de la sous-section suivante.

#### La discrépance

Afin d’éliminer les générateurs de nombres pseudo-aléatoires comme
l’exemple qu’on vient de citer, il faut étudier la répartition des
nombres. Sans tomber dans le cas pathologique de la section précédente,
on peut imaginer des nombres qui ont l’air aléatoires, mais qui ont un
biais. Reprenons l’exemple du tirage entre $[0,1]$. Nous pouvons
imaginer une suite très longue sans période avec des tirages aléatoires,
mais avec beaucoup plus de 0 que de 1, ce qui évidemment serait
problématique.

On doit donc trouver un moyen de tester la répartition des nombres de
façon plus quantitative. Une façon de le faire est de considérer
l’ensemble des $k-$uplets de nombres définis par
$$X^k=\{X_1,X_2, ..., X_k\},$$ où $X_0$ est supposé tiré uniformément
dans l’ensemble de départ (ici supposons que c’est $[0,1]$ à titre
d’exemple). En prenant toutes les graines existantes, on attend d’un bon
générateur qu’il recouvre tout l’espace des résultats possibles pour les
$k-$uplets formés avec des nombres aléatoires dans $[0,1]^k$. En
d’autres termes, il faut que des graines différentes génèrent des
$k-$uplets différents pour toutes valeurs de $k$.

De nouveau ce genre de tests est très compliqué à tester
expérimentalement pour $k$ de l’ordre de la période du générateur de
nombres aléatoires. Des analyses théoriques sont dès lors primordiales,
mais bien en dehors du champs de ce cours...

Il existe beaucoup d’autres possibilités (il y a des recommandations
sur le site `http://www.random.org`) pour tester des nombres aléatoires.
